INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zonda", "https://www.zondaglobal.com/", "https://zondaglobal.com/en/helpdesk/zonda-exchange/my-account/how-to-use-two-factor-authentication-provided-by-google-authenticator");
UPDATE "providers" SET name="Zoho" WHERE name="Zoho Mail";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zerodha Kite", "https://www.zerodha.com/", "https://support.zerodha.com/category/your-zerodha-account/login-credentials/login-credentials-of-trading-platforms/articles/time-based-otp-setup");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("YouHodler", "https://www.youhodler.com/", "https://help.youhodler.com/en/articles/3787039");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Xplenty", "https://www.xplenty.com/", "https://www.xplenty.com/docs/2-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Xink", "https://www.xink.io/", "https://support.xink.io/support/solutions/articles/1000271422");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wyze", "https://www.wyze.com/", "https://support.wyzecam.com/hc/en-us/articles/360024402052");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wrike", "https://www.wrike.com/", "https://help.wrike.com/hc/en-us/articles/210324445");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Workplace", "https://www.workplace.com/", "https://www.workplace.com/help/work/1331628866920315");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Workflowy", "https://www.workflowy.com/", "https://workflowy.zendesk.com/hc/en-us/articles/4401923146516");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Workato", "https://www.workato.com/", "https://docs.workato.com/security/two-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wordfence Central", "https://www.wordfence.com/", "https://www.wordfence.com/help/central/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WoltLab", "https://www.woltlab.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wolf.bet", "https://www.wolf.bet/", "https://www.youtube.com/watch?v=3B_zlGVldRY");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wiggle", "https://www.wiggle.co.uk/", "https://www.wiggle.com/h/option/verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Whois", "https://www.whois.com/", "https://manage.whois.com/kb/node/2690");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Whimsical", "https://www.whimsical.com/", "https://help.whimsical.com/article/664--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("When I Work", "https://www.wheniwork.com/", "https://help.wheniwork.com/articles/log-in-with-two-step-verification-computer/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Web Hosting Canada", "https://www.whc.ca/", "https://clients.whc.ca/en/knowledgebase/1430");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WhaleFin", "https://www.whalefin.com/", "https://support.whalefin.com/hc/en-us/articles/8911053323417");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WEDOS", "https://www.wedos.com/", "https://kb.wedos.com/cs/zakaznik/otp.html");
UPDATE "providers" SET help_url="https://answers.webroot.com/Webroot/ukp.aspx?vw=1&solid=3476" WHERE name="Webroot";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("POST Luxembourg", "https://www.webmail.pt.lu/", "https://support.pt.lu/2fa-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Webcentral", "https://www.webcentral.com.au/", "https://support.webcentral.com.au/s/article/Multi-Factor-Authentication-Guide");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("500px", "https://www.web.500px.com/", "https://support.500px.com/hc/en-us/articles/205115877");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wealthify", "https://www.wealthify.com/", "https://www.wealthify.com/faq#security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WazirX", "https://www.wazirx.com/", "https://support.wazirx.com/hc/en-us/articles/360014633494");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Warner Bros. Games", "https://www.warnerbrosgames.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Vysoká škola ekonomická v Praze", "https://www.vse.cz/", "https://ci.vse.cz/english/support/procedures/multi-factor-authentication-in-microsoft-365/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VoIP.ms", "https://www.voip.ms/", "https://wiki.voip.ms/article/TOTP_Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VMware", "https://www.vmware.com/", "https://kb.vmware.com/s/article/74603");
UPDATE "providers" SET website="https://www.visualstudio.microsoft.com/" WHERE name="Visual Studio Codespaces";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Vimeo", "https://www.vimeo.com/", "https://vimeo.zendesk.com/hc/en-us/articles/4856243815693");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VicRoads", "https://www.vicroads.vic.gov.au/", "https://www.vicroads.vic.gov.au/online-services/help-centre/two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Verpex", "https://www.verpex.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Veracode", "https://www.veracode.com/", "https://help.veracode.com/r/t_configure_mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VeeroTech", "https://www.veerotech.net/", "https://www.veerotech.net/kb/account-management-portal-two-factor-authentication-billing-support/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Laravel Vapor", "https://www.vapor.laravel.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Vancity", "https://www.vancity.com/", "https://support.vancity.com/what-is-multi-factor-authentication-and-how-does-it-work/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Valr", "https://www.valr.com/", "https://support.valr.com/hc/en-us/articles/360013860012");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fathom Analytics", "https://www.usefathom.com/", "https://usefathom.com/support/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Pennsylvania", "https://www.upenn.edu/", "https://www.isc.upenn.edu/how-to/two-step-verification-getting-started");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("UpdraftPlus", "https://www.updraftplus.com/", "https://updraftplus.com/my-account/two-factor-login-security-settings/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Unstoppable Domains", "https://www.unstoppabledomains.com/", "https://support.unstoppabledomains.com/support/solutions/articles/48001185664");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Unleashed Inventory", "https://www.unleashedsoftware.com/", "https://support.unleashedsoftware.com/hc/en-us/articles/4402216271001");
UPDATE "providers" SET website="https://www.unity.com/", help_url="https://support.unity.com/hc/en-us/articles/208764976" WHERE name="Unity";
UPDATE "providers" SET help_url="https://www.uniteddomains.com/twofactorauth/", name="ud.com" WHERE name="United Domains USA";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Unfuddle STACK", "https://www.unfuddle.com/", "https://unfuddle.com/stack/docs/help/two-factor-authentication/");
UPDATE "providers" SET name="Hosting Ukraine" WHERE name="Ukraine";
UPDATE "providers" SET help_url="https://www.uk2.net/knowledgebase/display/UK2/Two+Factor+Authentication+Security+-+2FA" WHERE name="UK2";
UPDATE "providers" SET help_url="https://help.ui.com/hc/en-us/articles/115012986607" WHERE name="Ubiquiti Inc";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Calgary", "https://www.ucalgary.ca/", "https://it.ucalgary.ca/mfa/gettingstarted");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Union Bank & Trust", "https://www.ubt.com/", "https://www.ubt.com/learning-center/blogs/multifactor-authentication-and-your-account");
UPDATE "providers" SET website="https://www.ubisoft.com/", help_url="https://www.ubisoft.com/help?article=000065723" WHERE name="Ubisoft/Uplay";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Uber Eats", "https://www.ubereats.com/", "https://help.uber.com/h/b8bb9152-8c91-4f49-83c4-35cf2e1dcf72");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Txbit", "https://www.txbit.io/", "https://support.txbit.io/support/solutions/articles/44000447137");
UPDATE "providers" SET help_url="https://help.twitter.com/en/managing-your-account/two-factor-authentication" WHERE name="Twitter";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tweakers", "https://www.tweakers.net/", "https://tweakers.net/plan/3096/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Technische Universität Berlin", "https://www.tu.berlin/", "https://www.campusmanagement.tu-berlin.de/menue/dienste/konto_karte/tan_verfahren/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("T. Rowe Price", "https://www.troweprice.com/", "https://www.troweprice.com/retirement-plan-services/en/our-advantage/cyber-security/multi-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Trovo", "https://www.trovo.live/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Trimble", "https://www.trimble.com/", "https://help.trimble.com/s/article/What-is-Multi-Factor-Authentication");
UPDATE "providers" SET help_url="https://support.atlassian.com/atlassian-account/docs/manage-two-step-verification-for-your-atlassian-account/" WHERE name="Trello";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Travala", "https://www.travala.com/", "https://blog.travala.com/explaining-how-the-travala-wallet-functions/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TradingView", "https://www.tradingview.com/", "https://www.tradingview.com/support/solutions/43000572460/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Trading 212", "https://www.trading212.com/", "https://helpcentre.trading212.com/hc/en-us/articles/360012452237");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Toshl", "https://www.toshl.com/", "https://toshl.com/blog/two-factor-authentication-and-how-to-use-it/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Toronto Metropolitan University", "https://www.torontomu.ca/", "https://www.torontomu.ca/ccs/services/ITSecurity/protecting-your-identity/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Todoist", "https://www.todoist.com/", "https://todoist.com/help/articles/how-to-enable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Timetastic", "https://www.timetastic.co.uk/", "https://help.timetastic.co.uk/hc/en-us/articles/360015994257");
UPDATE "providers" SET website="https://www.time4vps.com/", help_url="https://www.time4vps.com/knowledgebase/2-factor-authentication/" WHERE name="Time4VPS";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tito", "https://www.ti.to/", "https://help.tito.io/en/articles/3023132");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ThriveCart", "https://www.thrivecart.com/", "https://support.thrivecart.com/help/where-do-i-get-my-6-digit-access-code-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TherapyNotes", "https://www.therapynotes.com/", "https://support.therapynotes.com/article/231--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Textlocal", "https://www.textlocal.com/", "https://www.textlocal.com/support/knowledge-base/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Termius", "https://www.termius.com/", "https://support.termius.com/hc/en-us/articles/4402191604505#2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Telnyx", "https://www.telnyx.com/", "https://support.telnyx.com/en/articles/3739748");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Technic", "https://www.technicpack.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Teamwork", "https://www.teamwork.com/", "https://support.teamwork.com/projects/security/enabling-two-factor-authentication-on-your-profile");
UPDATE "providers" SET help_url="https://community.teamviewer.com/English/kb/articles/4711" WHERE name="TeamViewer";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TaxDome", "https://www.taxdome.com/", "https://help.taxdome.com/article/95--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TaxBit", "https://www.taxbit.com/", "https://help.taxbit.com/hc/en-us/articles/4410674012311");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tauros", "https://www.tauros.io/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Talkdesk", "https://www.talkdesk.com/", "https://support.talkdesk.com/hc/en-us/articles/360015179592");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Taboola", "https://www.taboola.com/", "https://help.taboola.com/hc/en-us/articles/360053360873");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tableau", "https://www.tableau.com/", "https://help.tableau.com/current/online/en-us/to_signin.htm#register-for-multifactor-authentication");
UPDATE "providers" SET help_url="https://www.t-mobile.com/support/account/set-up-and-manage-your-t-mobile-id#heading4" WHERE name="T-Mobile";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("System76", "https://www.system76.com/", "");
UPDATE "providers" SET help_url="https://kb.synology.com/en-us/DSM/help/DSM/SecureSignIn/2factor_authentication" WHERE name="Synology";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Swyftx", "https://www.swyftx.com/", "https://help.swyftx.com.au/en/articles/3573346");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Survicate", "https://www.survicate.com/", "https://help.survicate.com/en/articles/5006684");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Substack", "https://www.substack.com/", "https://support.substack.com/hc/en-us/articles/4785929336980");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Studio Ninja", "https://www.studioninja.co/", "https://help.studioninja.co/en/articles/4481947");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Federal Student Aid", "https://www.studentaid.gov/", "https://studentaid.gov/help-center/answers/topic/managing_your_account/article/choose-between-an-authenticator-app-text-email");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("STRATO", "https://www.strato.de/", "https://www.strato.de/faq/sicherheit/zwei-faktor-authentifizierung-einstellen/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("StormGain", "https://www.stormgain.com/", "https://support.stormgain.com/articles/two-factor-authentication-google-authenticator-and-sms");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Stessa", "https://www.stessa.com/", "https://support.stessa.com/en/articles/4649760#enabling-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Statuspage", "https://www.statuspage.io/", "https://support.atlassian.com/atlassian-account/docs/manage-two-step-verification-for-your-atlassian-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Standard Notes", "https://www.standardnotes.com/", "https://standardnotes.com/help/25");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MyFRITZ!", "https://www.sso.myfritz.net/", "https://en.avm.de/service/knowledge-base/dok/FRITZ-Box-7590/3602_Security-tips-for-using-MyFRITZ/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Square Enix", "https://www.square-enix-games.com/", "https://square-enix-games.com/en_US/seaccount/otp");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SproutSocial", "https://www.sproutsocial.com/", "https://support.sproutsocial.com/hc/en-us/articles/213938786");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Spring", "https://www.spri.ng/", "https://www.spri.ng/blog/two-factor-authentication-guide");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Spreedly", "https://www.spreedly.com/", "https://docs.spreedly.com/guides/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Splashtop", "https://www.splashtop.com/", "https://support-splashtopbusiness.splashtop.com/hc/en-us/articles/212724923");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SpectroCoin", "https://www.spectrocoin.com/", "https://blog.spectrocoin.com/en/how-to-enable-two-factor-authentication-at-spectrocoin/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SpaceHey", "https://www.spacehey.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SouthXchange", "https://www.southxchange.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sonix", "https://www.sonix.ai/", "https://help.sonix.ai/en/articles/4188823");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SolarWinds", "https://www.solarwinds.com/", "https://documentation.solarwinds.com/en/success_center/pingdom/content/shared/mfa-users.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Socialbakers", "https://www.socialbakers.com/", "https://support.socialbakers.com/hc/en-us/articles/360015072719");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SmartSurvey", "https://www.smartsurvey.co.uk/", "https://help.smartsurvey.co.uk/article/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Smartly.io", "https://www.smartly.io/", "https://support.smartly.io/hc/en-us/articles/360003493934");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Skinport", "https://www.skinport.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sketch", "https://www.sketch.com/", "https://www.sketch.com/docs/workspaces/managing-your-sketch-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sisense Cloud Data Teams", "https://www.sisense.com/", "https://dtdocs.sisense.com/article/two-factor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("sipgate", "https://www.sipgate.de/", "https://help.sipgate.de/hc/de/articles/4421549797649");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SimplyBook", "https://www.simplybook.me/", "https://help.simplybook.me/index.php/Google_Authenticator_custom_feature");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SimpleLogin", "https://www.simplelogin.io/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SignRequest", "https://www.signrequest.com/", "https://help.signrequest.com/hc/en-us/articles/360004932594");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Shrimpy", "https://www.shrimpy.io/", "https://help.shrimpy.io/hc/en-us/articles/1260803097310");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Shortcut", "https://www.shortcut.com/", "https://help.shortcut.com/hc/en-us/articles/360044506931");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Shift4Shop", "https://www.shift4shop.com/", "https://support.3dcart.com/knowledgebase/article/View/866/11/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Shareworks", "https://www.shareworks.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Simon Fraser University", "https://www.sfu.ca/", "https://www.sfu.ca/information-systems/services/mfa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("San Francisco Fire Credit Union", "https://www.sffirecu.org/", "https://sffirecu.org/how-to-use-a-2fa-application");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Serverspace", "https://www.serverspace.io/", "https://serverspace.io/support/help/how-to-install-and-use-the-google-authenticator-application/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ServerPilot", "https://www.serverpilot.io/", "https://serverpilot.io/docs/how-to-enable-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Server.pro", "https://www.server.pro/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wyre", "https://www.sendwyre.com/", "https://support.sendwyre.com/hc/en-us/articles/360057063573");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SendSafely", "https://www.sendsafely.com/", "https://blog.sendsafely.com/authenticator-app");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SendOwl", "https://www.sendowl.com/", "https://help.sendowl.com/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sendinblue", "https://www.sendinblue.com/", "https://help.sendinblue.com/hc/en-us/articles/360021203440");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sendcloud", "https://www.sendcloud.com/", "https://support.sendcloud.com/hc/en-gb/articles/4418777976212#1");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("State Employees Federal Credit Union", "https://www.sefcu.com/", "https://www.sefcu.com/node/11406/tutorial");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SecurityTrails", "https://www.securitytrails.com/", "https://securitytrails.com/support/knowledge-base/two-factor-authentication-2fa-2/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SeatGeek", "https://www.seatgeek.com/", "https://support.seatgeek.com/hc/en-us/articles/360007288013");
UPDATE "providers" SET help_url="https://www.scaleway.com/en/docs/how-to-activate-two-factor-authentication/" WHERE name="Scaleway";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ScaleGrid", "https://www.scalegrid.io/", "https://help.scalegrid.io/docs/account-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Scalefusion", "https://www.scalefusion.com/", "https://help.mobilock.in/article/6j7ps7cw8x");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sailthru", "https://www.sailthru.com/", "https://getstarted.sailthru.com/mfa/mfa-hub/login-mfa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Groningen", "https://www.rug.nl/", "https://www.rug.nl/society-business/centre-for-information-technology/security/multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Roblox", "https://www.roblox.com/", "https://en.help.roblox.com/hc/en-us/articles/212459863");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RMIT University", "https://www.rmit.edu.au/", "https://www.rmit.edu.au/students/support-and-facilities/it-services-for-students/cyber-safety/multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("River Financial", "https://www.river.com/", "https://river.com/support/knowledge-base/articles/enable-multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rippling", "https://www.rippling.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ring", "https://www.ring.com/", "https://support.ring.com/hc/en-us/articles/360039693891");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RightCapital", "https://www.rightcapital.com/", "https://help.rightcapital.com/article/40-two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rewind", "https://www.rewind.com/", "https://rewind.com/blog/how-to-set-up-a-2fa-for-rewind/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RevenueCat", "https://www.revenuecat.com/", "https://docs.revenuecat.com/docs/security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rev", "https://www.rev.com/", "https://support.rev.com/hc/en-us/articles/360035810851");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Republic", "https://www.republic.com/", "https://republic.com/help/how-do-i-add-a-digital-asset-wallet-on-republic-1");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Replicon", "https://www.replicon.com/", "https://www.replicon.com/help/setting-up-your-multi-factor-2-step-authentication-method/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Render", "https://www.render.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rejoiner", "https://www.rejoiner.com/", "https://docs.rejoiner.com/docs/user-account#managing-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Register365", "https://www.register365.com/", "https://www.register365.com/support/articles/enabling-two-factor-authentication-for-the-control-panel/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Refersion", "https://www.refersion.com/", "https://support.refersion.com/en/articles/2989703");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RedShelf", "https://www.redshelf.com/", "https://solve.redshelf.com/hc/en-us/articles/1260802590609");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Redis Enterprise Cloud", "https://www.redis.com/", "https://docs.redis.com/latest/rc/security/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Red Hat", "https://www.redhat.com/", "https://access.redhat.com/documentation/en-us/red_hat_customer_portal/1/html-single/using_two-factor_authentication/index");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Recruitee", "https://www.recruitee.com/", "https://support.recruitee.com/en/articles/5209837");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rebel.com", "https://www.rebel.com/", "https://support.rebel.com/hc/en-us/articles/360039417613");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RapidAPI", "https://www.rapidapi.com/", "https://docs.rapidapi.com/docs/account-creation-and-settings#two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ramp", "https://www.ramp.com/", "https://support.ramp.com/hc/en-us/articles/5775209997715");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Quidax", "https://www.quidax.com/", "https://support.quidax.com/hc/en-us/articles/360016734491");
UPDATE "providers" SET help_url="https://quickbooks.intuit.com/learn-support/en-us/manage-passwords/verify-your-account-with-multi-factor-authentication/00/186340" WHERE name="Quickbooks Online";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Questrade", "https://www.questrade.com/", "https://www.questrade.com/learning/questrade-basics/lesson/account-profile-and-security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Qantas", "https://www.qantas.com/", "https://qantas.com/au/en/frequent-flyer/member-account-security.html#frequently-asked-questions");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Putler", "https://www.putler.com/", "https://www.putler.com/documentation/activate-2fa-on-your-putler-account/");
UPDATE "providers" SET help_url="https://support.pushover.net/i49" WHERE name="Pushover";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pusher", "https://www.pusher.com/", "https://support.pusher.com/hc/en-us/articles/4411997260049");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Proton", "https://www.proton.me/", "https://proton.me/support/two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Protolabs", "https://www.protolabs.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Prostocash", "https://www.prostocash.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ProBit", "https://www.probit.com/", "https://support.probit.com/hc/en-us/sections/900000153103");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Practice Better", "https://www.practicebetter.io/", "https://help.practicebetter.io/hc/en-us/articles/360055519791");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PowerReviews", "https://www.powerreviews.com/", "https://help.powerreviews.com/Content/Support%20Topics/Two%20Factor%20Authentication.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Postman", "https://www.postman.com/", "https://learning.postman.com/docs/getting-started/postman-account/#setting-up-two-factor-authentication");
UPDATE "providers" SET help_url="https://support.poloniex.com/hc/en-us/articles/360040016513" WHERE name="Poloniex";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Poli Systems", "https://www.polisystems.ch/", "https://wiki.polisystems.ch/English/Tutorials/Two-factor-authentification-on-Poli-Systems-Portal/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("POEditor", "https://www.poeditor.com/", "https://poeditor.com/kb/how-to-enable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Podio", "https://www.podio.com/", "https://help.podio.com/hc/en-us/articles/360017456279");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Russian Post (Почта России)", "https://www.pochta.ru/", "");
UPDATE "providers" SET help_url="https://www.pobox.help/hc/en-us/sections/1500000033741" WHERE name="Pobox";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Black Desert", "https://www.playblackdesert.com/", "https://www.naeu.playblackdesert.com/en-US/News/Detail?groupContentNo=164");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Plesk 360", "https://www.platform360.io/", "https://docs.platform360.io/360/dashboard/user-profile/#multifactor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Planning Center", "https://www.planningcenter.com/", "https://support.planningcenteronline.com/hc/en-us/articles/6984288823579");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Plaid", "https://www.plaid.com/", "https://plaid.com/docs/account/security/#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pixieset", "https://www.pixieset.com/", "https://help.pixieset.com/hc/en-us/articles/360046803431");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Piwik PRO", "https://www.piwik.pro/", "https://help.piwik.pro/support/getting-started/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Phrase", "https://www.phrase.com/", "https://phrase.com/blog/posts/multi-factor-how-to-secure-your-account-using-multi-factor/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Philips Hue", "https://www.philips-hue.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Phemex", "https://www.phemex.com/", "https://phemex.com/getting-started/how-do-i-enable-google-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Personal Capital", "https://www.personalcapital.com/", "https://support.personalcapital.com/hc/en-us/sections/200230560");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Perimeter 81", "https://www.perimeter81.com/", "https://support.perimeter81.com/docs/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PC Case Gear", "https://www.pccasegear.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Payworks", "https://www.payworks.ca/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Paycor", "https://www.paycor.com/", "https://support.paycor.com/s/article/Multi-Factor-Authentication-MFA-Requirements-and-Setup");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Paxos", "https://www.paxos.com/", "https://help.paxos.com/hc/en-us/articles/360042320451");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Paxful", "https://www.paxful.com/", "https://paxful.com/support/en-us/articles/360012619094");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Passfolio", "https://www.passfolio.us/", "https://www.passfolio.com/posts/how-to-use-authy-for-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Particle", "https://www.particle.io/", "https://docs.particle.io/tutorials/developer-tools/two-step-authentication/");
UPDATE "providers" SET website="https://www.parsec.app/", help_url="https://support.parsec.app/hc/en-us/articles/4424732242445" WHERE name="Parsec";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Paritex", "https://www.paritex.com/", "https://paritex.freshdesk.com/en/support/solutions/folders/44001201778");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Parimatch", "https://www.parimatch.com/", "https://faq.parimatch.com/en/account-access-and-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Parallels", "https://www.parallels.com/", "https://kb.parallels.com/125441");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OzBargain", "https://www.ozbargain.com.au/", "https://ozbargain.com.au/node/449886");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Oxford", "https://www.ox.ac.uk/", "https://help.it.ox.ac.uk/mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Outbrain", "https://www.outbrain.com/", "https://www.outbrain.com/help/advertisers/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Otago", "https://www.otago.ac.nz/", "https://otago.custhelp.com/app/answers/detail/a_id/3073");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("The Ohio State University", "https://www.osu.edu/", "https://buckeyepass.osu.edu");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Open Science Framework (OSF)", "https://www.osf.io/", "https://help.osf.io/article/239--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Optimizely", "https://www.optimizely.com/", "https://help.optimizely.com/Account_Settings/Protect_your_account_with_individual_2-step_verification");
UPDATE "providers" SET website="https://www.openprovider.com/" WHERE name="Openprovider";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Open Collective", "https://www.opencollective.com/", "https://docs.opencollective.com/help/fiscal-hosts/payouts/two-factor-authentication-for-payouts#enabling-2fa-for-login");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Malwarebytes OneView", "https://www.oneview.malwarebytes.com/", "https://support.malwarebytes.com/hc/en-us/articles/360039863254");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Onet", "https://www.onet.pl/", "https://pomoc.poczta.onet.pl/baza-wiedzy/czym-jest-weryfikacja-dwuetapowa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OneSignal", "https://www.onesignal.com/", "https://documentation.onesignal.com/docs/two-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Onehub", "https://www.onehub.com/", "https://support.onehub.com/hc/en-us/articles/360039792571");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("One.com", "https://www.one.com/", "https://help.one.com/hc/en-us/articles/4404699986321");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Labcorp OnDemand", "https://www.ondemand.labcorp.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OKX", "https://www.okx.com/", "https://www.okx.com/support/hc/en-us/articles/360000350271");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Oculus", "https://www.oculus.com/", "https://support.oculus.com/357942391637117/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nuri", "https://www.nuri.com/", "https://support.nuri.com/hc/en-gb/articles/360021689979");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nozbe Teams", "https://www.nozbe.com/", "https://nozbe.help/management/settings/#settings_2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Notejoy", "https://www.notejoy.com/", "https://notejoy.com/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Norton", "https://www.norton.com/", "https://support.norton.com/sp/en/us/home/current/solutions/v100023155_NortonM_Retail_1_en_us");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NordVPN", "https://www.nordvpn.com/", "https://support.nordvpn.com/1755768802/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NordLocker", "https://www.nordlocker.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NordLayer", "https://www.nordlayer.com/", "https://help.nordlayer.com/docs/mfa-sso");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("No-IP", "https://www.noip.com/", "https://www.noip.com/support/knowledgebase/two-factor-authentication-last-pass/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nimbus Note", "https://www.nimbusweb.me/", "https://nimbusweb.me/feature-2-step-verification.php");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nifty", "https://www.niftypm.com/", "https://help.niftypm.com/en/articles/5356559");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NiceHash", "https://www.nicehash.com/", "https://www.nicehash.com/support/general-help/security/how-to-setup-2fa-security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Niagahoster", "https://www.niagahoster.co.id/", "https://www.niagahoster.co.id/kb/fitur-keamanan-terbaru-member-area-niagahoster-two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NextDNS", "https://www.nextdns.io/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nexcess", "https://www.nexcess.net/", "https://help.nexcess.net/client-portal/how-to-use-two-factor-authentication-in-the-client-portal");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Newgrounds", "https://www.newgrounds.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Maropost Commerce Cloud", "https://www.netohq.com/", "https://www.netohq.com/support/s/article/multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Netim", "https://www.netim.com/", "https://support.netim.com/en/wiki/2FA");
UPDATE "providers" SET name="netcup" WHERE name="Netcup";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Netcore Cloud Email API", "https://www.netcorecloud.com/", "https://emaildocs.netcorecloud.com/docs/two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nest", "https://www.nest.com/", "https://support.google.com/googlenest/answer/9295081");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NDAX", "https://www.ndax.io/", "https://help.ndax.io/en-ca/category/2fa-rgk6to/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Notre Dame", "https://www.nd.edu/", "https://nd.service-now.com/nd_portal?id=kb_article_view&sysparm_article=KB0017218");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NameHero", "https://www.namehero.com/", "https://www.namehero.com/knowledgebase/163");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Namebase", "https://www.namebase.io/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NairaEx", "https://www.nairaex.com/", "https://support.nairaex.com/support/solutions/articles/43000335554");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NAGA", "https://www.naga.com/", "https://support.naga.com/en/articles/5052755");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("N-able", "https://www.n-able.com/", "https://documentation.n-able.com/covedataprotection/USERGUIDE/documentation/Content/service-management/console/sso_migration.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pennsylvania Dept of Revenue myPATH", "https://www.mypath.pa.gov/", "https://revenue-pa.custhelp.com/app/answers/detail/a_id/3939");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MYOB", "https://www.myob.com/", "https://help.myob.com/wiki/x/bwfq");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Emma Email Marketing", "https://www.myemma.com/", "https://support.e2ma.net/s/article/Two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MyAnimeList", "https://www.myanimelist.net/", "https://myanimelist.net/about.php?go=support");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MxToolbox", "https://www.mxtoolbox.com/", "https://mxtoolbox.com/support/knowledgebase/?faq=455");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MURAL", "https://www.mural.co/", "https://support.mural.co/en/articles/5315716");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Masaryk University", "https://www.muni.cz/", "https://it.muni.cz/en/services/jednotne-prihlaseni-na-muni/navody/how-to-set-up-multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mos.ru", "https://www.mos.ru/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Morgan Stanley", "https://www.morganstanley.com/", "https://www.morganstanley.com/what-we-do/wealth-management/online-security/authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Moqups", "https://www.moqups.com/", "https://support.moqups.com/hc/en-us/articles/360019781980#account_2FA");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MongoDB", "https://www.mongodb.com/", "https://docs.atlas.mongodb.com/security-multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Monex", "https://www.monex.co.jp/", "https://info.monex.co.jp/help/security/mfa/index.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Monday.com", "https://www.monday.com/", "https://support.monday.com/hc/en-us/articles/360000787745");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mist", "https://www.mist.com/", "https://www.mist.com/documentation/two-factor-authentication-mobile-authenticator/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Miro", "https://www.miro.com/", "https://help.miro.com/hc/en-us/articles/7935469290002");
UPDATE "providers" SET website="https://www.mint.intuit.com/", help_url="https://accounts-help.intuit.com/app/intuit/1995176" WHERE name="Mint";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mineplex", "https://www.mineplex.com/", "https://www.mineplex.com/threads/239/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Minecraft", "https://www.minecraft.net/", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Meta", "https://www.meta.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mercury", "https://www.mercury.com/", "https://help.mercury.com/t/m1h3d07");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mercury Cash", "https://www.mercury.cash/", "https://support.mercury.cash/en/articles/3881123");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mercado Libre", "https://www.mercadolibre.com/", "https://www.mercadolivre.com.br/ajuda/945");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Memsource", "https://www.memsource.com/", "https://help.memsource.com/hc/en-us/articles/360014479359#two-factor-authentication-0-0");
UPDATE "providers" SET website="https://www.mega.io/", help_url="https://mega.io/help/client/webclient/security-and-privacy#5bb525f9f1b70989348b45de" WHERE name="Mega";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Meet", "https://www.meet.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mattermost", "https://www.mattermost.com/", "https://docs.mattermost.com/onboard/multi-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Matomo Cloud", "https://www.matomo.org/", "https://matomo.org/faq/general/faq_27245/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Make", "https://www.make.com/", "https://support.integromat.com/hc/en-us/articles/360017490699");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mailo", "https://www.mailo.com/", "https://faq.mailo.com/acces/activer-la-double-authentification.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Yahoo Mail", "https://www.mail.yahoo.com/", "https://help.yahoo.com/kb/SLN5013.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SAPO Mail", "https://www.mail.sapo.pt/", "https://ajuda.sapo.pt/id-67553");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mail.com", "https://www.mail.com/", "https://support.mail.com/security/2fa/index.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mountain America Credit Union", "https://www.macu.com/", "");
UPDATE "providers" SET help_url="https://docs.macstadium.com/docs/two-factor-authentication" WHERE name="MacStadium";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("M1 Finance", "https://www.m1finance.com/", "https://support.m1finance.com/hc/en-us/articles/221056367");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Lokalise", "https://www.lokalise.com/", "https://docs.lokalise.com/en/articles/2329387");
UPDATE "providers" SET help_url="https://documentation.logmein.com/webhelp/SecDoc/LogMeIn/t_login_policy_Set_TwoFactor_OwnAccount.html" WHERE name="LogMeIn";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Logitech", "https://www.logitech.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LocalMonero", "https://www.localmonero.co/", "https://localmonero.co/guides/2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Localize", "https://www.localizejs.com/", "https://help.localizejs.com/docs/users-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LIHKG", "https://www.lihkg.com/", "https://help.lihkg.com/privacy/account-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LCN.com", "https://www.lcn.com/", "https://www.lcn.com/support/articles/how-to-set-up-and-use-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LaunchDarkly", "https://www.launchdarkly.com/", "https://docs.launchdarkly.com/home/account-security/mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LATOKEN", "https://www.latoken.com/", "https://latoken.zendesk.com/hc/en-us/articles/360010034040");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Larian", "https://www.larian.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Krystal", "https://www.krystal.uk/", "https://help.krystal.uk/getting-started/how-do-i-setup-two-factor-authentication-2-fa-on-my-krystal-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kriptomat", "https://www.kriptomat.io/", "https://help.kriptomat.io/en/articles/1986160");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Knack", "https://www.knack.com/", "https://learn.knack.com/article/seuor9vxmw");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Klaviyo", "https://www.klaviyo.com/", "https://help.klaviyo.com/hc/en-us/articles/360026617692");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kintone", "https://www.kintone.com/", "https://get.kintone.help/general/en/user/list_personal/two_factor_authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kinsta", "https://www.kinsta.com/", "https://kinsta.com/knowledgebase/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("KickEX", "https://www.kickex.com/", "https://support.kickex.com/hc/en-us/articles/360019513860");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("justhost", "https://www.justhost.com/", "https://my.justhost.com/hosting/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("JumpCloud", "https://www.jumpcloud.com/", "https://support.jumpcloud.com/support/s/article/using-multi-factor-authentication-with-your-jumpcloud-user-account-2019-08-21-10-36-47");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Jovia Financial", "https://www.jovia.org/", "https://www.jovia.org/knowledge-base/how-do-i-enable-authenticator-apps-within-online-and-mobile-banking");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mastodon", "https://www.joinmastodon.org/", "https://github.com/McKael/mastodon-documentation/blob/master/Using-Mastodon/2FA.md");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nutstore", "https://www.jianguoyun.com/", "https://help.jianguoyun.com/?p=1251");
UPDATE "providers" SET help_url="https://sales.jetbrains.com/hc/en-gb/articles/360013015240" WHERE name="JetBrains";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Jamf Now", "https://www.jamfnow.com/", "https://support.jamfnow.com/s/article/207717923-How-to-turn-on-Two-Factor-Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Iterable", "https://www.iterable.com/", "https://support.iterable.com/hc/en-us/articles/115004821703");
UPDATE "providers" SET name="IONOS" WHERE name="1&1 IONOS";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Voyager", "https://www.investvoyager.com/", "https://support.investvoyager.com/support/solutions/43000367274");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Intuit", "https://www.intuit.com/", "https://accounts-help.intuit.com/app/intuit/1995123");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("InterServer", "https://www.interserver.net/", "https://www.interserver.net/tips/kb/enable-two-factor-authentication-in-a-cpanel-account/");
UPDATE "providers" SET website="https://www.internetbs.net/", help_url="https://2fa.directory/notes/internetbs/" WHERE name="Internet.bs";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("InMotion Hosting", "https://www.inmotionhosting.com/", "https://www.inmotionhosting.com/support/edu/cpanel/how-to-configure-and-use-two-factor-authentication/");
UPDATE "providers" SET help_url="https://www.infomaniak.com/en/support/faq/1940" WHERE name="Infomaniak";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Independer", "https://www.independer.nl/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Independent Reserve", "https://www.independentreserve.com/", "https://blog.independentreserve.com/knowledge-base/setting-up-2fa-using-google-authenticator");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ImprovMX", "https://www.improvmx.com/", "http://help.improvmx.com/en/articles/4892466");
UPDATE "providers" SET help_url="https://sicherheit.immobilienscout24.de/2-faktor-authentifizierung.html" WHERE name="ImmobilienScout24";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IDrive", "https://www.idrive.com/", "https://www.idrive.com/online-backup-web-faq#twostep");
UPDATE "providers" SET help_url="https://support.atlassian.com/atlassian-account/docs/manage-two-step-verification-for-your-atlassian-account/" WHERE name="Atlassian Cloud";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hypixel", "https://www.hypixel.net/", "https://support.hypixel.net/hc/en-us/articles/360019538060");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Huobi", "https://www.huobi.com/", "https://huobiglobal.zendesk.com/hc/en-us/articles/360000191282");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Huawei Cloud", "https://www.huaweicloud.com/", "https://support.huaweicloud.com/intl/en-us/usermanual-iam/iam_10_0002.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HP", "https://www.hp.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hotjar", "https://www.hotjar.com/", "https://help.hotjar.com/hc/en-us/articles/4406998019223");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostwinds", "https://www.hostwinds.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HostMonster", "https://www.hostmonster.com/", "https://my.hostmonster.com/cgi/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostinger", "https://www.hostinger.com/", "https://support.hostinger.com/articles/4888148");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostek", "https://www.hostek.com/", "https://wiki.hostek.com/Client_Area_-_Two_Factor_Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Honeybadger", "https://www.honeybadger.io/", "https://www.honeybadger.io/blog/account-security-updates/#how-to-enable");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sophos Home", "https://www.home.sophos.com/", "https://support.home.sophos.com/hc/en-us/articles/360032204471");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Saxo Bank", "https://www.home.saxo/", "https://www.help.saxo/hc/en-us/articles/360038307372");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Home Assistant", "https://www.home-assistant.io/", "https://www.home-assistant.io/docs/authentication/multi-factor-auth/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HMRC", "https://www.hmrc.gov.uk/", "https://www.gov.uk/government/publications/genuine-hmrc-contact-and-recognising-phishing-emails/genuine-hmrc-contact-and-recognising-phishing-emails#hmrc-short-message-service-text-messages");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HiDrive (STRATO)", "https://www.hidrive.com/", "https://www.strato.de/faq/cloud-speicher/2-Faktor-Authentifizierung/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("hide.me VPN", "https://www.hide.me/", "https://hide.me/en/blog/hide-me-vpn-now-supports-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hevo Data", "https://www.hevodata.com/", "https://docs.hevodata.com/account-management/personal-settings/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hetzner", "https://www.hetzner.com/", "https://docs.hetzner.com/accounts-panel/accounts/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Stake", "https://www.hellostake.com/", "https://hellostake.com/au/support/wall-st/articles/35000152372");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VRChat", "https://www.hello.vrchat.com/", "https://docs.vrchat.com/docs/setup-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Heap", "https://www.heap.io/", "https://help.heap.io/heap-administration/secure-access/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hatch", "https://www.hatchinvest.nz/", "https://help.hatchinvest.nz/en/articles/2996776");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HappyFox", "https://www.happyfox.com/", "https://support.happyfox.com/kb/article/709--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hack The Box", "https://www.hackthebox.com/", "https://help.hackthebox.com/articles/5185265");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Guilded", "https://www.guilded.gg/", "https://support.guilded.gg/hc/en-us/articles/1500008991902");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Guideline", "https://www.guideline.com/", "https://success.guideline.com/hc/articles/360034791412");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GreenGeeks", "https://www.greengeeks.com/", "https://www.greengeeks.com/support/article/two-factor-authentication-greengeeks/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Teleport", "https://www.goteleport.com/", "https://goteleport.com/docs/access-controls/guides/webauthn/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Госуслуги (Gosuslugi)", "https://www.gosuslugi.ru/", "https://www.gosuslugi.ru/help/faq/login/101923");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GoSquared", "https://www.gosquared.com/", "https://www.gosquared.com/support/articles/6493653");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Abode", "https://www.goabode.com/", "https://help.goabode.com/hc/en-us/articles/360022414751");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GMX.com", "https://www.gmx.com/", "https://support.gmx.com/security/2fa/setup-twofactor.html#indexlink_help_security_2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Glassdoor", "https://www.glassdoor.com/", "https://help.glassdoor.com/article/Manage-Two-Factor-Authentication/");
UPDATE "providers" SET help_url="https://docs.github.com/en/github/authenticating-to-github/securing-your-account-with-two-factor-authentication-2fa/configuring-two-factor-authentication" WHERE name="GitHub";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Getscreen.me", "https://www.getscreen.me/", "https://getscreen.me/en/docs/dashboard#account-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pocket", "https://www.getpocket.com/", "https://support.mozilla.org/en-US/kb/secure-firefox-account-two-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GeForce (Nvidia)", "https://www.geforce.com/", "https://login.nvgs.nvidia.com/v1/help/nfactor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gate.io", "https://www.gate.io/", "https://www.gate.io/help/question/16445");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GameMaker", "https://www.gamemaker.io/", "https://help.yoyogames.com/hc/en-us/articles/216757288");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Galaxus", "https://www.galaxus.ch/", "https://www.galaxus.ch/en/page/6589");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FTX", "https://www.ftx.com/", "https://help.ftx.com/hc/en-us/articles/360033774352");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Frontify", "https://www.frontify.com/", "https://help.frontify.com/en/articles/3947094");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Freshworks", "https://www.freshworks.com/", "https://support.freshworks.com/support/solutions/articles/50000001025");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Freewallet", "https://www.freewallet.org/", "https://freewallet.org/blog/2fa-faq");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Freehostia", "https://www.freehostia.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Frame", "https://www.frame.io/", "https://support.frame.io/en/articles/4766302");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FragDenStaat", "https://www.fragdenstaat.de/", "https://fragdenstaat.de/hilfe/ihr-konto-verwalten/zwei-faktor-login/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Formspree", "https://www.formspree.io/", "https://help.formspree.io/hc/articles/4407875207187");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Formsite", "https://www.formsite.com/", "https://support.formsite.com/hc/en-us/articles/360000686614");
UPDATE "providers" SET name="FogBugz" WHERE name="FogBugz & Kiln";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Flourish", "https://www.flourish.studio/", "https://help.flourish.studio/article/362--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Firmex VDR", "https://www.firmex.com/", "https://support.firmex.com/hc/en-us/articles/204467648");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Finnair", "https://www.finnair.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Finary", "https://www.finary.com/", "https://help.finary.com/en/article/18z52w/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Filen", "https://www.filen.io/", "https://support.filen.io/knowledgebase.php?article=20");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Favro", "https://www.favro.com/", "https://help.favro.com/en/articles/1019897");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fauna", "https://www.fauna.com/", "https://docs.fauna.com/fauna/current/integrations/dashboard/mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FaucetPay", "https://www.faucetpay.io/", "https://faq.faucetpay.io/knowledge-base/what-is-2fa-and-how-do-i-enable-it-in-my-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Faucet Crypto", "https://www.faucetcrypto.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fathom", "https://www.fathomhq.com/", "https://support.fathomhq.com/en/articles/4483786");
UPDATE "providers" SET name="Fastmail" WHERE name="FastMail";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FastComet", "https://www.fastcomet.com/", "https://www.fastcomet.com/tutorials/getting-started/enabling-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FanDuel", "https://www.fanduel.com/", "https://www.fanduel.com/2fa-how-it-works");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Falcon", "https://www.falcon.io/", "https://help.falcon.io/hc/en-us/articles/360027689451");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Exmo", "https://www.exmo.com/", "https://info.exmo.com/en/education/how-to-enable-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("eUKhost", "https://www.eukhost.com/", "https://www.eukhost.com/kb/how-to-enable-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Etana Custody", "https://www.etana.com/", "https://support.etana.com/hc/en-us/articles/360053109333");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ESET HOME", "https://www.eset.com/", "https://help.eset.com/home_eset/en-US/two_factor_authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Epik", "https://www.epik.com/", "https://www.epik.com/support/how-to-add-2-factor-authentication-on-epik/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("E.ON", "https://www.eon.de/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Envoyer", "https://www.envoyer.io/", "https://docs.envoyer.io/1.0/accounts/your-account.html#securing-your-account-with-two-factor-authentication");
UPDATE "providers" SET help_url="https://enom.help/2fa" WHERE name="eNom";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Eneba", "https://www.eneba.com/", "https://support.eneba.com/hc/en-us/articles/360010216714");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("EmailMeForm", "https://www.emailmeform.com/", "https://support.emailmeform.com/hc/en-us/sections/360002042671");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Elastic Cloud", "https://www.elastic.co/", "https://www.elastic.co/guide/en/cloud/current/ec-account-user-settings.html#ec-account-security-mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Egnyte", "https://www.egnyte.com/", "https://helpdesk.egnyte.com/hc/en-us/articles/360028032991");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("eclincher", "https://www.eclincher.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("EasySendy", "https://www.easysendy.com/", "https://easysendy.com/sendy/sendy-version-2-1-0-two-factor-authentication-released");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Earth Class Mail", "https://www.earthclassmail.com/", "https://help.earthclassmail.com/hc/en-us/articles/4410499059351");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Drift", "https://www.drift.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Doppler", "https://www.doppler.com/", "https://docs.doppler.com/docs/security-fact-sheet#user-authentication");
UPDATE "providers" SET help_url="https://docs.docker.com/docker-hub/2fa/" WHERE name="Docker";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DNSFilter", "https://www.dnsfilter.com/", "https://help.dnsfilter.com/hc/en-us/articles/4419435706003");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DMOJ", "https://www.dmoj.ca/", "https://dmoj.ca/post/144-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DMM", "https://www.dmm.com/", "https://support.dmm.com/accounts/article/46818");
UPDATE "providers" SET website="https://www.discord.com/", help_url="https://support.discord.com/hc/en-us/articles/219576828" WHERE name="Discord";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Discogs", "https://www.discogs.com/", "https://support.discogs.com/hc/en-us/articles/4403461442317");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Digital Surge", "https://www.digitalsurge.com.au/", "https://help.digitalsurge.com.au/en/articles/5573002");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DCS World", "https://www.digitalcombatsimulator.com/", "https://www.digitalcombatsimulator.com/en/support/faq/User_profile/#3319486");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dext Prepare", "https://www.dext.com/", "https://help.receipt-bank.com/hc/articles/360002530177");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Detectify", "https://www.detectify.com/", "https://support.detectify.com/support/solutions/articles/48001061904");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Deputy", "https://www.deputy.com/", "https://help.deputy.com/en/articles/1953504");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Demio", "https://www.demio.com/", "https://help.demio.com/en/articles/4794494");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Delinea", "https://www.delinea.com/", "https://docs.delinea.com/ss/10.8.0/authentication/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Deel", "https://www.deel.com/", "https://help.letsdeel.com/hc/en-gb/articles/4407737656465");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Datto", "https://www.datto.com/", "https://help.datto.com/s/article/KB360032979352");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DataRobot", "https://www.datarobot.com/", "https://docs.datarobot.com/en/docs/platform/authentication/2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Databox", "https://www.databox.com/", "https://help.databox.com/article/515--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Current RMS", "https://www.current-rms.com/", "https://help.current-rms.com/en/articles/1767596");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Crowd Supply", "https://www.crowdsupply.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Credly", "https://www.credly.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CrashPlan", "https://www.crashplan.com/", "https://support.code42.com/Small_Business/Get_Started/Two-factor_authentication_for_CrashPlan_for_Small_Business");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cal Poly Pomona", "https://www.cpp.edu/", "https://cpp.service-now.com/ehelp?id=kb_article&sys_id=ed4dcbc3dbeb1f449bba68461b96198e");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coursera", "https://www.coursera.org/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cordial", "https://www.cordial.com/", "https://support.cordial.com/hc/en-us/articles/360004846512");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Constellix", "https://www.constellix.com/", "https://support.constellix.com/support/solutions/articles/47001012279");
UPDATE "providers" SET help_url="https://www.compose.com/articles/introducing-fido-universal-2nd-factor-authentication/" WHERE name="Compose";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CommunityAmerica", "https://www.communityamerica.com/", "https://www.cacuonlinebanking.com/tob/live/usp-core/static/help.html#login_security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinzilla", "https://www.coinzilla.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cointraffic", "https://www.cointraffic.io/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinTiger", "https://www.cointiger.com/", "https://cointiger.zendesk.com/hc/en-us/articles/360009805534");
UPDATE "providers" SET name="CoinSpot" WHERE name="Coinspot";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinSmart", "https://www.coinsmart.com/", "https://coinsmart.zendesk.com/hc/en-us/articles/360014948893");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinRemitter", "https://www.coinremitter.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinPayU", "https://www.coinpayu.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinPayments", "https://www.coinpayments.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinLoan", "https://www.coinloan.io/", "https://blog.coinloan.io/securing-your-accounts-with-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinigy", "https://www.coinigy.com/", "https://support.coinigy.com/hc/en-us/articles/360001134694");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinField", "https://www.coinfield.com/", "https://coinfield.freshdesk.com/support/solutions/folders/36000055721");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinDCX", "https://www.coindcx.com/", "https://support.coindcx.com/hc/en-gb/articles/360003181855");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinberry", "https://www.coinberry.com/", "https://help.coinberry.com/hc/en-us/articles/4505782775569");
UPDATE "providers" SET help_url="https://help.coinbase.com/en/coinbase/getting-started/verify-my-account/how-do-i-set-up-2-factor-authentication" WHERE name="Coinbase";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Codeberg", "https://www.codeberg.org/", "https://docs.codeberg.org/security/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Codebase", "https://www.codebasehq.com/", "https://support.codebasehq.com/articles/tips-tricks/how-do-i-setup-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coda", "https://www.coda.io/", "https://help.coda.io/en/articles/3833338");
UPDATE "providers" SET help_url="https://cobaltio.zendesk.com/hc/en-us/articles/4408918977940" WHERE name="Cobalt";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Clover", "https://www.clover.com/", "https://www.clover.com/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("cloudHQ", "https://www.cloudhq.net/", "https://support.cloudhq.net/how-to-set-up-and-enable-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CloudBees", "https://www.cloudbees.com/", "https://docs.cloudbees.com/docs/cloudbees-feature-management/latest/security/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CloudAMQP", "https://www.cloudamqp.com/", "https://www.cloudamqp.com/blog/two-factor-authentication.html");
UPDATE "providers" SET help_url="https://help.cloud66.com/node/account/two-factor-authentication.html" WHERE name="Cloud 66";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Oracle Cloud Infrastructure", "https://www.cloud.oracle.com/", "https://docs.oracle.com/en/cloud/paas/identity-cloud/uaids/configure-authentication-factors.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Malwarebytes Nebula", "https://www.cloud.malwarebytes.com/", "https://support.malwarebytes.com/hc/en-us/articles/360042186433");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HashiCorp Cloud Platform", "https://www.cloud.hashicorp.com/", "https://cloud.hashicorp.com/docs/hcp/mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cliniko", "https://www.cliniko.com/", "https://help.cliniko.com/en/articles/1023989");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ClickUp", "https://www.clickup.com/", "https://docs.clickup.com/en/articles/2601429");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CleverTap", "https://www.clevertap.com/", "https://docs.clevertap.com/docs/account-security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ClearScore", "https://www.clearscore.com/", "https://help.clearscore.com/hc/en-us/sections/360003360940");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cisco", "https://www.cisco.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Checkfront", "https://www.checkfront.com/", "https://support.checkfront.com/hc/en-us/articles/115003849053");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Chatwork", "https://www.chatwork.com/", "https://support-en.chatwork.com/hc/en-us/articles/360023097632");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Chat", "https://www.chat.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
UPDATE "providers" SET website="https://www.central.sophos.com/" WHERE name="Sophos Central";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Celsius", "https://www.celsius.network/", "https://support.celsius.network/hc/en-us/articles/360002047837");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Caspio", "https://www.caspio.com/", "https://howto.caspio.com/caspio-id/managing-caspio-id/#Enable2FA");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cash App", "https://www.cash.app/", "https://cash.app/help/en/en-us/3127");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cardmarket", "https://www.cardmarket.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Campaign Monitor", "https://www.campaignmonitor.com/", "https://help.campaignmonitor.com/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Cambridge", "https://www.cam.ac.uk/", "https://help.uis.cam.ac.uk/service/accounts-passwords/set-multi-factor-authentication-your-university-microsoft-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("bunny.net", "https://www.bunny.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BullionVault", "https://www.bullionvault.com/", "https://www.bullionvault.com/help/two_factor_auth.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BullionStar", "https://www.bullionstar.com/", "https://www.bullionstar.com/help/2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buildium", "https://www.buildium.com/", "https://www.buildium.com/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buhl", "https://www.buhl.de/", "https://www.buhl.de/shop/faqs?category=325");
UPDATE "providers" SET website="https://www.buffer.com/", help_url="https://buffer.com/resources/introducing-the-safest-social-media-publishing-on-the-web/" WHERE name="Buffer";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bubble", "https://www.bubble.io/", "https://bubble.io/support-article/what-is-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BtcTurk", "https://www.btcturk.com/", "https://www.btcturk.com/yardim/guvenlik");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Brex", "https://www.brex.com/", "https://www.brex.com/support/how-do-i-opt-in-for-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Box", "https://www.box.com/", "https://support.box.com/hc/en-us/articles/360043697154");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bonusly", "https://www.bonus.ly/", "https://help.bonus.ly/en/articles/2889878");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bokio Sverige", "https://www.bokio.se/", "https://www.bokio.se/hjalp/bokio-medlemskap/ditt-bokiokonto/tvafaktor-autentisering-med-bokio/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BnkToTheFuture", "https://www.bnktothefuture.com/", "https://bnktothefuture.freshdesk.com/support/solutions/articles/9000068450");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BlueSnap", "https://www.bluesnap.com/", "https://support.bluesnap.com/docs/two-factor_authentication");
UPDATE "providers" SET help_url="https://help.blockfi.com/hc/en-us/articles/360049343611" WHERE name="BlockFi";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Blockchain.com", "https://www.blockchain.com/", "https://support.blockchain.com/hc/en-us/articles/4417080375316");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BKEX", "https://www.bkex.com/", "https://bkex.zendesk.com/hc/en-us/articles/360021899473");
UPDATE "providers" SET name="Bitwarden" WHERE name="bitwarden";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitso", "https://www.bitso.com/", "https://help.bitso.com/en/support/solutions/articles/1000166781");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitSight", "https://www.bitsight.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitrise", "https://www.bitrise.io/", "https://devcenter.bitrise.io/getting-started/account-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitForex", "https://www.bitforex.com/", "https://support.bitforex.com/hc/en-us/articles/360006825152");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitbuy", "https://www.bitbuy.ca/", "https://support.bitbuy.ca/hc/en-us/articles/360059151172");
UPDATE "providers" SET help_url="https://support.atlassian.com/bitbucket-cloud/docs/enable-two-step-verification/" WHERE name="Bitbucket";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitbns", "https://www.bitbns.com/", "https://bitbns.freshdesk.com/support/solutions/articles/35000047047");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitBar", "https://www.bitbar.com/", "https://bitbar.com/blog/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bill", "https://www.bill.com/", "https://help.bill.com/hc/en-us/articles/360000023843");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bibox", "https://www.bibox.com/", "https://support.bibox.jp/hc/en-us/articles/900006744823");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Barmenia", "https://www.barmenia.de/", "https://www.barmenia.de/deu/bde_privat/bde_service/bde_selfservice/bde_meine_barmenia/erstanmeldung.xhtml");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Baremetrics", "https://www.baremetrics.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Balena", "https://www.balena.io/", "https://www.balena.io/docs/learn/manage/account/#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Deutsche Bahn (DB)", "https://www.bahn.com/", "https://www.bahn.de/hilfe/kundenkonto/kundenkonto-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Back4App", "https://www.back4app.com/", "https://www.back4app.com/docs/security/multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Awin", "https://www.awin.com/", "https://success.awin.com/s/article/How-to-activate-and-deactivate-the-Two-Step-Verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AVG", "https://www.avg.com/", "https://support.avg.com/SupportArticleView?l=en&urlname=AVG-Account-2-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Avast", "https://www.avast.com/", "https://support.avast.com/en-gb/article/Account-2-Step-Verification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Automate.io", "https://www.automate.io/", "https://docs.automate.io/en/articles/3068223");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Auth0", "https://www.auth0.com/", "https://auth0.com/docs/secure/multi-factor-authentication/enable-mfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Aussie Broadband", "https://www.aussiebroadband.com.au/", "https://www.aussiebroadband.com.au/help-centre/business/6-carbon/how-to-enable-2-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Audiense", "https://www.audiense.com/", "https://help.audiense.com/knowledge/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Atera", "https://www.atera.com/", "https://support.atera.com/hc/en-us/articles/360022522253");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Assembla", "https://www.assembla.com/", "https://articles.assembla.com/en/articles/1914077");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Asana", "https://www.asana.com/", "https://asana.com/guide/help/fundamentals/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ARIN", "https://www.arin.net/", "https://www.arin.net/reference/materials/security/twofactor/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Arduino", "https://www.arduino.cc/", "https://support.arduino.cc/hc/en-us/articles/360018131120");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Flexera Software Vulnerability Research", "https://www.app.flexera.com/", "https://docs.flexera.com/svr/ug/Content/helplibrary/Configure_Two_Factor_Authentication__2FA_.htm");
UPDATE "providers" SET help_url="https://anycoindirect.eu/en/support/anycoin-direct/security#what-is-two-factor-authentication-2fa", name="Anycoin Direct" WHERE name="AnycoinDirect";
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ANY.RUN", "https://www.any.run/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AnonAddy", "https://www.anonaddy.com/", "https://anonaddy.com/security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Amazing Marvin", "https://www.amazingmarvin.com/", "https://help.amazingmarvin.com/en/articles/5019430");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Alterdice", "https://www.alterdice.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AltCoinTrader", "https://www.altcointrader.co.za/", "https://altcointrader.zendesk.com/hc/en-gb/articles/360007179680");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Allegro", "https://www.allegro.pl/", "https://allegro.pl/pomoc/dla-kupujacych/logowanie-i-haslo/dwustopniowe-logowanie-najczesciej-zadawane-pytania-dykqg9nMKSZ");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Alchemer", "https://www.alchemer.com/", "https://help.alchemer.com/help/multi-factor-authentication#user");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Aiven", "https://www.aiven.io/", "https://help.aiven.io/en/articles/947120");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Adyen", "https://www.adyen.com/", "https://docs.adyen.com/account/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Activision", "https://www.activision.com/", "https://support.activision.com/articles/using-two-factor-authentication-with-an-activision-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ActiveCampaign", "https://www.activecampaign.com/", "https://help.activecampaign.com/hc/en-us/articles/360008574740");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Actionstep", "https://www.actionstep.com/", "https://www.intercom.com/help/en/articles/181");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Accelo", "https://www.accelo.com/", "https://www.accelo.com/resources/help/faq/user-permissions-and-settings/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Contra Costa Community College District", "https://www.4cd.edu/", "https://4cd-doit.atlassian.net/wiki/spaces/ITPU/pages/2320465929");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("3Commas", "https://www.3commas.io/", "https://help.3commas.io/en/articles/3424452");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("2Checkout", "https://www.2checkout.com/", "https://knowledgecenter.2checkout.com/Onboarding/Activate-and-set-up-your-2Checkout-account/Two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("15Five", "https://www.15five.com/", "https://success.15five.com/hc/en-us/articles/360002698811");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("123 Form Builder", "https://www.123formbuilder.com/", "https://www.123formbuilder.com/docs/multi-factor-authentication-login");
