DELETE FROM "providers" WHERE "name"="AirVPN";
DELETE FROM "providers" WHERE "name"="IVPN";
DELETE FROM "providers" WHERE "name"="NordVPN Teams";
DELETE FROM "providers" WHERE "name"="Private Internet Access";
DELETE FROM "providers" WHERE "name"="ProtonVPN";
DELETE FROM "providers" WHERE "name"="Surfshark";
DELETE FROM "providers" WHERE "name"="TorGuard";
DELETE FROM "providers" WHERE "name"="VPN Unlimited";
DELETE FROM "providers" WHERE "name"="Windscribe";
DELETE FROM "providers" WHERE "name"="Andrews & Arnold";
DELETE FROM "providers" WHERE "name"="Con Edison";
DELETE FROM "providers" WHERE "name"="Google Fi";
DELETE FROM "providers" WHERE "name"="Google Fiber";
DELETE FROM "providers" WHERE "name"="Republic Wireless";
DELETE FROM "providers" WHERE "name"="Sonic";
DELETE FROM "providers" WHERE "name"="T-Mobile";
DELETE FROM "providers" WHERE "name"="Telzio";
DELETE FROM "providers" WHERE "name"="Ting";
DELETE FROM "providers" WHERE "name"="Uber";
DELETE FROM "providers" WHERE "name"="Airtable";
DELETE FROM "providers" WHERE "name"="Clubhouse";
DELETE FROM "providers" WHERE "name"="Meistertask";
DELETE FROM "providers" WHERE "name"="Microsoft To-Do";
DELETE FROM "providers" WHERE "name"="Planio";
DELETE FROM "providers" WHERE "name"="Toodledo";
DELETE FROM "providers" WHERE "name"="Trello";
DELETE FROM "providers" WHERE "name"="Buffer";
DELETE FROM "providers" WHERE "name"="Facebook";
DELETE FROM "providers" WHERE "name"="HootSuite";
DELETE FROM "providers" WHERE "name"="Instagram";
DELETE FROM "providers" WHERE "name"="LinkedIn";
DELETE FROM "providers" WHERE "name"="Lobsters";
DELETE FROM "providers" WHERE "name"="Plurk";
DELETE FROM "providers" WHERE "name"="Reddit";
DELETE FROM "providers" WHERE "name"="Restream.io";
DELETE FROM "providers" WHERE "name"="Short.io";
DELETE FROM "providers" WHERE "name"="Snapchat";
DELETE FROM "providers" WHERE "name"="Tumblr";
DELETE FROM "providers" WHERE "name"="Twitter";
DELETE FROM "providers" WHERE "name"="VK";
DELETE FROM "providers" WHERE "name"="WordPress.com";
DELETE FROM "providers" WHERE "name"="Wykop";
DELETE FROM "providers" WHERE "name"="XING";
DELETE FROM "providers" WHERE "name"="AdGuard";
DELETE FROM "providers" WHERE "name"="Bitdefender";
DELETE FROM "providers" WHERE "name"="Blur";
DELETE FROM "providers" WHERE "name"="Boxcryptor";
DELETE FROM "providers" WHERE "name"="bugcrowd";
DELETE FROM "providers" WHERE "name"="Cloudflare";
DELETE FROM "providers" WHERE "name"="Cobalt";
DELETE FROM "providers" WHERE "name"="DigiCert";
DELETE FROM "providers" WHERE "name"="DMARC Analyzer";
DELETE FROM "providers" WHERE "name"="dmarcian";
DELETE FROM "providers" WHERE "name"="Dome9 Security";
DELETE FROM "providers" WHERE "name"="EasyDMARC";
DELETE FROM "providers" WHERE "name"="HackerOne";
DELETE FROM "providers" WHERE "name"="intigriti";
DELETE FROM "providers" WHERE "name"="Kaspersky";
DELETE FROM "providers" WHERE "name"="Panther";
DELETE FROM "providers" WHERE "name"="Prey";
DELETE FROM "providers" WHERE "name"="Pwnie Express Pwn Pulse";
DELETE FROM "providers" WHERE "name"="RBLTracker";
DELETE FROM "providers" WHERE "name"="Sophos Central";
DELETE FROM "providers" WHERE "name"="SSLTrust";
DELETE FROM "providers" WHERE "name"="ThreatConnect";
DELETE FROM "providers" WHERE "name"="ThreatX";
DELETE FROM "providers" WHERE "name"="Tinfoil Security";
DELETE FROM "providers" WHERE "name"="VirusTotal";
DELETE FROM "providers" WHERE "name"="Webroot";
DELETE FROM "providers" WHERE "name"="Adafruit";
DELETE FROM "providers" WHERE "name"="Amazon";
DELETE FROM "providers" WHERE "name"="Best Buy";
DELETE FROM "providers" WHERE "name"="Digitec";
DELETE FROM "providers" WHERE "name"="Etsy";
DELETE FROM "providers" WHERE "name"="Migros";
DELETE FROM "providers" WHERE "name"="Newegg";
DELETE FROM "providers" WHERE "name"="Purse";
DELETE FROM "providers" WHERE "name"="Samsung";
DELETE FROM "providers" WHERE "name"="Shopify";
DELETE FROM "providers" WHERE "name"="Tokopedia";
DELETE FROM "providers" WHERE "name"="AnyDesk";
DELETE FROM "providers" WHERE "name"="ConnectWise Control (ScreenConnect)";
DELETE FROM "providers" WHERE "name"="DirectAdmin";
DELETE FROM "providers" WHERE "name"="ISL Online";
DELETE FROM "providers" WHERE "name"="join.me (w/ LogMeIn account)";
DELETE FROM "providers" WHERE "name"="LogMeIn";
DELETE FROM "providers" WHERE "name"="MB Connect Line";
DELETE FROM "providers" WHERE "name"="O&O Syspectr";
DELETE FROM "providers" WHERE "name"="RealVNC";
DELETE FROM "providers" WHERE "name"="Remote Desktop Manager";
DELETE FROM "providers" WHERE "name"="TeamViewer";
DELETE FROM "providers" WHERE "name"="Amazon Pay";
DELETE FROM "providers" WHERE "name"="AppFolio";
DELETE FROM "providers" WHERE "name"="Braintree";
DELETE FROM "providers" WHERE "name"="Chargebee";
DELETE FROM "providers" WHERE "name"="Dwolla";
DELETE FROM "providers" WHERE "name"="GoCardless";
DELETE FROM "providers" WHERE "name"="Google Pay";
DELETE FROM "providers" WHERE "name"="NETELLER";
DELETE FROM "providers" WHERE "name"="PayPal";
DELETE FROM "providers" WHERE "name"="Paysafecard";
DELETE FROM "providers" WHERE "name"="Privacy";
DELETE FROM "providers" WHERE "name"="Ravelin";
DELETE FROM "providers" WHERE "name"="Skrill";
DELETE FROM "providers" WHERE "name"="Square";
DELETE FROM "providers" WHERE "name"="Stripe";
DELETE FROM "providers" WHERE "name"="Tebex";
DELETE FROM "providers" WHERE "name"="WePay";
DELETE FROM "providers" WHERE "name"="Yandex.Money";
DELETE FROM "providers" WHERE "name"="Adobe ID";
DELETE FROM "providers" WHERE "name"="AngelList";
DELETE FROM "providers" WHERE "name"="Autodesk";
DELETE FROM "providers" WHERE "name"="Automater";
DELETE FROM "providers" WHERE "name"="AwardWallet";
DELETE FROM "providers" WHERE "name"="Basic Attention Token";
DELETE FROM "providers" WHERE "name"="CharlieHR";
DELETE FROM "providers" WHERE "name"="Chartbeat";
DELETE FROM "providers" WHERE "name"="Cisco Meraki";
DELETE FROM "providers" WHERE "name"="CloudConvert";
DELETE FROM "providers" WHERE "name"="Cloudinary";
DELETE FROM "providers" WHERE "name"="Contentful";
DELETE FROM "providers" WHERE "name"="Envato";
DELETE FROM "providers" WHERE "name"="Figma";
DELETE FROM "providers" WHERE "name"="Findmyshift";
DELETE FROM "providers" WHERE "name"="Firefox";
DELETE FROM "providers" WHERE "name"="Formstack";
DELETE FROM "providers" WHERE "name"="Grammarly";
DELETE FROM "providers" WHERE "name"="GrowingIO";
DELETE FROM "providers" WHERE "name"="Help Scout";
DELETE FROM "providers" WHERE "name"="ImmobilienScout24";
DELETE FROM "providers" WHERE "name"="Jitbit Helpdesk";
DELETE FROM "providers" WHERE "name"="Kayako";
DELETE FROM "providers" WHERE "name"="Kickstarter";
DELETE FROM "providers" WHERE "name"="MathWorks";
DELETE FROM "providers" WHERE "name"="No Starch Press";
DELETE FROM "providers" WHERE "name"="Office 365";
DELETE FROM "providers" WHERE "name"="Onshape";
DELETE FROM "providers" WHERE "name"="Opera";
DELETE FROM "providers" WHERE "name"="Patreon";
DELETE FROM "providers" WHERE "name"="PhraseApp";
DELETE FROM "providers" WHERE "name"="Repairshopr";
DELETE FROM "providers" WHERE "name"="Ripe NCC";
DELETE FROM "providers" WHERE "name"="SaneBox";
DELETE FROM "providers" WHERE "name"="SmartSimple";
DELETE FROM "providers" WHERE "name"="Teespring";
DELETE FROM "providers" WHERE "name"="Ubiquiti Inc";
DELETE FROM "providers" WHERE "name"="Upwork";
DELETE FROM "providers" WHERE "name"="Usabilla";
DELETE FROM "providers" WHERE "name"="Watchman Monitoring";
DELETE FROM "providers" WHERE "name"="Weclapp";
DELETE FROM "providers" WHERE "name"="Wikipedia";
DELETE FROM "providers" WHERE "name"="Yclas";
DELETE FROM "providers" WHERE "name"="YourAcclaim";
DELETE FROM "providers" WHERE "name"="Zendesk";
DELETE FROM "providers" WHERE "name"="Clio";
DELETE FROM "providers" WHERE "name"="Docusign";
DELETE FROM "providers" WHERE "name"="Everlaw";
DELETE FROM "providers" WHERE "name"="HelloSign";
DELETE FROM "providers" WHERE "name"="ecobee";
DELETE FROM "providers" WHERE "name"="IFTTT";
DELETE FROM "providers" WHERE "name"="Samsung SmartThings";
DELETE FROM "providers" WHERE "name"="Tesla";
DELETE FROM "providers" WHERE "name"="AJ Bell Youinvest";
DELETE FROM "providers" WHERE "name"="Betterment";
DELETE FROM "providers" WHERE "name"="Mintos";
DELETE FROM "providers" WHERE "name"="Nutmeg";
DELETE FROM "providers" WHERE "name"="Robinhood";
DELETE FROM "providers" WHERE "name"="SelfWealth";
DELETE FROM "providers" WHERE "name"="Wealthfront";
DELETE FROM "providers" WHERE "name"="Wealthsimple";
DELETE FROM "providers" WHERE "name"="1Password";
DELETE FROM "providers" WHERE "name"="bitwarden";
DELETE FROM "providers" WHERE "name"="Centrify";
DELETE FROM "providers" WHERE "name"="Dashlane";
DELETE FROM "providers" WHERE "name"="ID.me";
DELETE FROM "providers" WHERE "name"="Keeper";
DELETE FROM "providers" WHERE "name"="LastPass";
DELETE FROM "providers" WHERE "name"="NordPass";
DELETE FROM "providers" WHERE "name"="Okta";
DELETE FROM "providers" WHERE "name"="OneLogin";
DELETE FROM "providers" WHERE "name"="ORCID";
DELETE FROM "providers" WHERE "name"="Passwarden";
DELETE FROM "providers" WHERE "name"="RoboForm";
DELETE FROM "providers" WHERE "name"="20i";
DELETE FROM "providers" WHERE "name"="34SP.com";
DELETE FROM "providers" WHERE "name"="A2 Hosting";
DELETE FROM "providers" WHERE "name"="Acquia";
DELETE FROM "providers" WHERE "name"="ACTIVE 24";
DELETE FROM "providers" WHERE "name"="ALL-INKL.COM";
DELETE FROM "providers" WHERE "name"="Binary Lane";
DELETE FROM "providers" WHERE "name"="Binero";
DELETE FROM "providers" WHERE "name"="Blacknight";
DELETE FROM "providers" WHERE "name"="Bluehost";
DELETE FROM "providers" WHERE "name"="BunnyCDN";
DELETE FROM "providers" WHERE "name"="Carrd";
DELETE FROM "providers" WHERE "name"="CDN77";
DELETE FROM "providers" WHERE "name"="CDNsun";
DELETE FROM "providers" WHERE "name"="Cloudways";
DELETE FROM "providers" WHERE "name"="Contabo";
DELETE FROM "providers" WHERE "name"="cyon";
DELETE FROM "providers" WHERE "name"="Dreamhost";
DELETE FROM "providers" WHERE "name"="Easy";
DELETE FROM "providers" WHERE "name"="Fastly";
DELETE FROM "providers" WHERE "name"="Flywheel";
DELETE FROM "providers" WHERE "name"="Glesys";
DELETE FROM "providers" WHERE "name"="Greenhost";
DELETE FROM "providers" WHERE "name"="Hetzner Online";
DELETE FROM "providers" WHERE "name"="Hostens";
DELETE FROM "providers" WHERE "name"="Hostpoint";
DELETE FROM "providers" WHERE "name"="HostUS";
DELETE FROM "providers" WHERE "name"="ICDSoft";
DELETE FROM "providers" WHERE "name"="ICUK";
DELETE FROM "providers" WHERE "name"="Infomaniak";
DELETE FROM "providers" WHERE "name"="INIZ";
DELETE FROM "providers" WHERE "name"="IO Zoom";
DELETE FROM "providers" WHERE "name"="KnownHost";
DELETE FROM "providers" WHERE "name"="Liquid Web";
DELETE FROM "providers" WHERE "name"="Mammoth Networks";
DELETE FROM "providers" WHERE "name"="Miss Hosting";
DELETE FROM "providers" WHERE "name"="NearlyFreeSpeech.NET";
DELETE FROM "providers" WHERE "name"="Neolo";
DELETE FROM "providers" WHERE "name"="Netcup";
DELETE FROM "providers" WHERE "name"="Netlify";
DELETE FROM "providers" WHERE "name"="Nitrado";
DELETE FROM "providers" WHERE "name"="Noez";
DELETE FROM "providers" WHERE "name"="Oderland";
DELETE FROM "providers" WHERE "name"="OMGServ";
DELETE FROM "providers" WHERE "name"="Online";
DELETE FROM "providers" WHERE "name"="OVH";
DELETE FROM "providers" WHERE "name"="PlanetHoster";
DELETE FROM "providers" WHERE "name"="RamNode";
DELETE FROM "providers" WHERE "name"="RunCloud";
DELETE FROM "providers" WHERE "name"="section.io";
DELETE FROM "providers" WHERE "name"="Segment";
DELETE FROM "providers" WHERE "name"="SiteGround";
DELETE FROM "providers" WHERE "name"="Squarespace";
DELETE FROM "providers" WHERE "name"="StackPath";
DELETE FROM "providers" WHERE "name"="Time4VPS";
DELETE FROM "providers" WHERE "name"="TransIP";
DELETE FROM "providers" WHERE "name"="UKFast";
DELETE FROM "providers" WHERE "name"="Ukraine";
DELETE FROM "providers" WHERE "name"="UpCloud";
DELETE FROM "providers" WHERE "name"="VentraIP";
DELETE FROM "providers" WHERE "name"="Versio";
DELETE FROM "providers" WHERE "name"="VPS Server";
DELETE FROM "providers" WHERE "name"="WebFaction";
DELETE FROM "providers" WHERE "name"="Webflow";
DELETE FROM "providers" WHERE "name"="Wedos";
DELETE FROM "providers" WHERE "name"="World4You";
DELETE FROM "providers" WHERE "name"="WP Engine";
DELETE FROM "providers" WHERE "name"="23andMe";
DELETE FROM "providers" WHERE "name"="Cronometer";
DELETE FROM "providers" WHERE "name"="FollowMyHealth";
DELETE FROM "providers" WHERE "name"="Google Fit";
DELETE FROM "providers" WHERE "name"="Hint Health";
DELETE FROM "providers" WHERE "name"="MyHeritage";
DELETE FROM "providers" WHERE "name"="RunSignUp";
DELETE FROM "providers" WHERE "name"="login.gov";
DELETE FROM "providers" WHERE "name"="RealMe";
DELETE FROM "providers" WHERE "name"="US Citizenship and Immigration Services";
DELETE FROM "providers" WHERE "name"="Ashes of Creation";
DELETE FROM "providers" WHERE "name"="Aternos";
DELETE FROM "providers" WHERE "name"="Bethesda";
DELETE FROM "providers" WHERE "name"="Black Desert Online";
DELETE FROM "providers" WHERE "name"="Blade & Soul";
DELETE FROM "providers" WHERE "name"="Bohemia Interactive";
DELETE FROM "providers" WHERE "name"="Call Of Duty";
DELETE FROM "providers" WHERE "name"="Electronic Arts (Origin)";
DELETE FROM "providers" WHERE "name"="Epic Games";
DELETE FROM "providers" WHERE "name"="ESL";
DELETE FROM "providers" WHERE "name"="EVE Online";
DELETE FROM "providers" WHERE "name"="FaceIT";
DELETE FROM "providers" WHERE "name"="Fanatical";
DELETE FROM "providers" WHERE "name"="Gaijin Entertainment";
DELETE FROM "providers" WHERE "name"="GREE";
DELETE FROM "providers" WHERE "name"="Guild Wars 2";
DELETE FROM "providers" WHERE "name"="Humble Bundle";
DELETE FROM "providers" WHERE "name"="itch.io";
DELETE FROM "providers" WHERE "name"="lichess.org";
DELETE FROM "providers" WHERE "name"="Nexon";
DELETE FROM "providers" WHERE "name"="Nexus Mods";
DELETE FROM "providers" WHERE "name"="Nintendo Account";
DELETE FROM "providers" WHERE "name"="Parsec";
DELETE FROM "providers" WHERE "name"="Playstation Network";
DELETE FROM "providers" WHERE "name"="Razer";
DELETE FROM "providers" WHERE "name"="Roberts Space Industries";
DELETE FROM "providers" WHERE "name"="Rockstar Games Social Club";
DELETE FROM "providers" WHERE "name"="RuneScape";
DELETE FROM "providers" WHERE "name"="Scryfall";
DELETE FROM "providers" WHERE "name"="Tibia";
DELETE FROM "providers" WHERE "name"="Toontown Rewritten";
DELETE FROM "providers" WHERE "name"="Ubisoft/Uplay";
DELETE FROM "providers" WHERE "name"="Wargaming";
DELETE FROM "providers" WHERE "name"="Xbox Live";
DELETE FROM "providers" WHERE "name"="YoYo Games";
DELETE FROM "providers" WHERE "name"="AltoIRA";
DELETE FROM "providers" WHERE "name"="BGL Corporate Solutions";
DELETE FROM "providers" WHERE "name"="Bitbond";
DELETE FROM "providers" WHERE "name"="Carta";
DELETE FROM "providers" WHERE "name"="DEGIRO";
DELETE FROM "providers" WHERE "name"="Exact Online";
DELETE FROM "providers" WHERE "name"="Expensify";
DELETE FROM "providers" WHERE "name"="FreeAgent";
DELETE FROM "providers" WHERE "name"="FreeTaxUSA";
DELETE FROM "providers" WHERE "name"="Gusto";
DELETE FROM "providers" WHERE "name"="H&R Block";
DELETE FROM "providers" WHERE "name"="Intuit TurboTax";
DELETE FROM "providers" WHERE "name"="Justworks";
DELETE FROM "providers" WHERE "name"="Metorik";
DELETE FROM "providers" WHERE "name"="Mint";
DELETE FROM "providers" WHERE "name"="Moneybird";
DELETE FROM "providers" WHERE "name"="Northwestern Mutual";
DELETE FROM "providers" WHERE "name"="Pocketsmith";
DELETE FROM "providers" WHERE "name"="Principal";
DELETE FROM "providers" WHERE "name"="Quickbooks Online";
DELETE FROM "providers" WHERE "name"="QuickFile";
DELETE FROM "providers" WHERE "name"="SimpleTax";
DELETE FROM "providers" WHERE "name"="Taxact";
DELETE FROM "providers" WHERE "name"="Xero";
DELETE FROM "providers" WHERE "name"="You Need A Budget (YNAB)";
DELETE FROM "providers" WHERE "name"="Floatplane";
DELETE FROM "providers" WHERE "name"="Google Play";
DELETE FROM "providers" WHERE "name"="Niconico";
DELETE FROM "providers" WHERE "name"="Plex";
DELETE FROM "providers" WHERE "name"="Rocket Beans TV";
DELETE FROM "providers" WHERE "name"="smashcast";
DELETE FROM "providers" WHERE "name"="Twitch";
DELETE FROM "providers" WHERE "name"="YouTube";
DELETE FROM "providers" WHERE "name"="FastMail";
DELETE FROM "providers" WHERE "name"="Gmail";
DELETE FROM "providers" WHERE "name"="GMX.net";
DELETE FROM "providers" WHERE "name"="HEY";
DELETE FROM "providers" WHERE "name"="Hushmail";
DELETE FROM "providers" WHERE "name"="mail.de";
DELETE FROM "providers" WHERE "name"="mailbox.org";
DELETE FROM "providers" WHERE "name"="Mailfence";
DELETE FROM "providers" WHERE "name"="Migadu";
DELETE FROM "providers" WHERE "name"="Mimecast";
DELETE FROM "providers" WHERE "name"="Outlook.com";
DELETE FROM "providers" WHERE "name"="Pobox";
DELETE FROM "providers" WHERE "name"="Posteo";
DELETE FROM "providers" WHERE "name"="ProtonMail";
DELETE FROM "providers" WHERE "name"="Runbox";
DELETE FROM "providers" WHERE "name"="StartMail";
DELETE FROM "providers" WHERE "name"="Thexyz";
DELETE FROM "providers" WHERE "name"="Tutanota";
DELETE FROM "providers" WHERE "name"="Web.de";
DELETE FROM "providers" WHERE "name"="Yahoo Japan Mail";
DELETE FROM "providers" WHERE "name"="Yandex.Mail";
DELETE FROM "providers" WHERE "name"="Zimbra";
DELETE FROM "providers" WHERE "name"="Zoho Mail";
DELETE FROM "providers" WHERE "name"="(ISC)2";
DELETE FROM "providers" WHERE "name"="East Carolina University";
DELETE FROM "providers" WHERE "name"="itslearning";
DELETE FROM "providers" WHERE "name"="Karlsruher Institut für Technologie";
DELETE FROM "providers" WHERE "name"="KnowBe4";
DELETE FROM "providers" WHERE "name"="McGill University";
DELETE FROM "providers" WHERE "name"="North Carolina State University";
DELETE FROM "providers" WHERE "name"="Philipps-Universität Marburg";
DELETE FROM "providers" WHERE "name"="Pluralsight";
DELETE FROM "providers" WHERE "name"="Ryerson University";
DELETE FROM "providers" WHERE "name"="University of Delaware";
DELETE FROM "providers" WHERE "name"="007Names";
DELETE FROM "providers" WHERE "name"="1&1 IONOS";
DELETE FROM "providers" WHERE "name"="101domain";
DELETE FROM "providers" WHERE "name"="Above.com";
DELETE FROM "providers" WHERE "name"="ClouDNS";
DELETE FROM "providers" WHERE "name"="Directnic";
DELETE FROM "providers" WHERE "name"="DNS Made Easy";
DELETE FROM "providers" WHERE "name"="DNSimple";
DELETE FROM "providers" WHERE "name"="Domeneshop";
DELETE FROM "providers" WHERE "name"="Dyn";
DELETE FROM "providers" WHERE "name"="Dynadot";
DELETE FROM "providers" WHERE "name"="Dynu";
DELETE FROM "providers" WHERE "name"="easyDNS";
DELETE FROM "providers" WHERE "name"="eNom";
DELETE FROM "providers" WHERE "name"="EuroDNS";
DELETE FROM "providers" WHERE "name"="Fabulous";
DELETE FROM "providers" WHERE "name"="Fasthosts";
DELETE FROM "providers" WHERE "name"="Gandi";
DELETE FROM "providers" WHERE "name"="GoDaddy";
DELETE FROM "providers" WHERE "name"="Google Domains";
DELETE FROM "providers" WHERE "name"="Hexonet";
DELETE FROM "providers" WHERE "name"="Hover.com";
DELETE FROM "providers" WHERE "name"="Hurricane Electric";
DELETE FROM "providers" WHERE "name"="Imperva";
DELETE FROM "providers" WHERE "name"="Internet.bs";
DELETE FROM "providers" WHERE "name"="INWX";
DELETE FROM "providers" WHERE "name"="Joker.com";
DELETE FROM "providers" WHERE "name"="Moniker";
DELETE FROM "providers" WHERE "name"="Name.com";
DELETE FROM "providers" WHERE "name"="Namecheap";
DELETE FROM "providers" WHERE "name"="Namesco";
DELETE FROM "providers" WHERE "name"="NameSilo.com";
DELETE FROM "providers" WHERE "name"="NearlyFreeSpeech.net";
DELETE FROM "providers" WHERE "name"="Nominet";
DELETE FROM "providers" WHERE "name"="NS1";
DELETE FROM "providers" WHERE "name"="OpenDNS";
DELETE FROM "providers" WHERE "name"="Openprovider";
DELETE FROM "providers" WHERE "name"="OpenSRS";
DELETE FROM "providers" WHERE "name"="pair Domains";
DELETE FROM "providers" WHERE "name"="Porkbun";
DELETE FROM "providers" WHERE "name"="Rebrandly";
DELETE FROM "providers" WHERE "name"="Register4Less";
DELETE FROM "providers" WHERE "name"="Registro.br";
DELETE FROM "providers" WHERE "name"="Synergy Wholesale";
DELETE FROM "providers" WHERE "name"="UK2";
DELETE FROM "providers" WHERE "name"="Uniregistry";
DELETE FROM "providers" WHERE "name"="United Domains USA";
DELETE FROM "providers" WHERE "name"="united-domains Reselling";
DELETE FROM "providers" WHERE "name"="united-domains.de";
DELETE FROM "providers" WHERE "name"="VentraIP";
DELETE FROM "providers" WHERE "name"="ActiveState";
DELETE FROM "providers" WHERE "name"="Airbrake";
DELETE FROM "providers" WHERE "name"="Algolia";
DELETE FROM "providers" WHERE "name"="AppSignal";
DELETE FROM "providers" WHERE "name"="AppVeyor";
DELETE FROM "providers" WHERE "name"="aTech Media";
DELETE FROM "providers" WHERE "name"="Atlassian Cloud";
DELETE FROM "providers" WHERE "name"="Batch";
DELETE FROM "providers" WHERE "name"="Bitbucket";
DELETE FROM "providers" WHERE "name"="Buddy";
DELETE FROM "providers" WHERE "name"="Bugsnag";
DELETE FROM "providers" WHERE "name"="Bugzilla@Mozilla";
DELETE FROM "providers" WHERE "name"="Buildkite";
DELETE FROM "providers" WHERE "name"="BuiltWith";
DELETE FROM "providers" WHERE "name"="Codeship";
DELETE FROM "providers" WHERE "name"="Compose";
DELETE FROM "providers" WHERE "name"="Crowdin";
DELETE FROM "providers" WHERE "name"="DeployHQ";
DELETE FROM "providers" WHERE "name"="Docker";
DELETE FROM "providers" WHERE "name"="Domino Data Lab";
DELETE FROM "providers" WHERE "name"="Drupal.org";
DELETE FROM "providers" WHERE "name"="elmah.io";
DELETE FROM "providers" WHERE "name"="Esri";
DELETE FROM "providers" WHERE "name"="FogBugz & Kiln";
DELETE FROM "providers" WHERE "name"="GitHub";
DELETE FROM "providers" WHERE "name"="GitLab";
DELETE FROM "providers" WHERE "name"="HashiCorp Terraform Enterprise";
DELETE FROM "providers" WHERE "name"="HashiCorp Vagrant Cloud";
DELETE FROM "providers" WHERE "name"="Heap Analytics";
DELETE FROM "providers" WHERE "name"="InVision";
DELETE FROM "providers" WHERE "name"="IT Glue";
DELETE FROM "providers" WHERE "name"="JetBrains";
DELETE FROM "providers" WHERE "name"="Koding";
DELETE FROM "providers" WHERE "name"="Launchpad";
DELETE FROM "providers" WHERE "name"="Looker";
DELETE FROM "providers" WHERE "name"="Mapbox";
DELETE FROM "providers" WHERE "name"="Metrological";
DELETE FROM "providers" WHERE "name"="MongoDB Cloud Manager";
DELETE FROM "providers" WHERE "name"="npm";
DELETE FROM "providers" WHERE "name"="NuGet";
DELETE FROM "providers" WHERE "name"="Packagist";
DELETE FROM "providers" WHERE "name"="Panic Sync";
DELETE FROM "providers" WHERE "name"="Phacility";
DELETE FROM "providers" WHERE "name"="Pivotal Tracker";
DELETE FROM "providers" WHERE "name"="ProfitWell";
DELETE FROM "providers" WHERE "name"="Pushover";
DELETE FROM "providers" WHERE "name"="PyPI";
DELETE FROM "providers" WHERE "name"="PythonAnywhere";
DELETE FROM "providers" WHERE "name"="Raygun";
DELETE FROM "providers" WHERE "name"="RBCommons";
DELETE FROM "providers" WHERE "name"="ReadMe";
DELETE FROM "providers" WHERE "name"="Report URI";
DELETE FROM "providers" WHERE "name"="Rollbar";
DELETE FROM "providers" WHERE "name"="RubyGems.org";
DELETE FROM "providers" WHERE "name"="Scripting Helpers";
DELETE FROM "providers" WHERE "name"="Semaphore";
DELETE FROM "providers" WHERE "name"="Sentry";
DELETE FROM "providers" WHERE "name"="SourceForge";
DELETE FROM "providers" WHERE "name"="StatusCake";
DELETE FROM "providers" WHERE "name"="Sumo Logic";
DELETE FROM "providers" WHERE "name"="Twilio";
DELETE FROM "providers" WHERE "name"="Unbounce";
DELETE FROM "providers" WHERE "name"="Unity";
DELETE FROM "providers" WHERE "name"="Uptime Robot";
DELETE FROM "providers" WHERE "name"="Visual Studio Codespaces";
DELETE FROM "providers" WHERE "name"="Zapier";
DELETE FROM "providers" WHERE "name"="AnycoinDirect";
DELETE FROM "providers" WHERE "name"="Bcnex";
DELETE FROM "providers" WHERE "name"="Binance";
DELETE FROM "providers" WHERE "name"="BitBay";
DELETE FROM "providers" WHERE "name"="Bitcoin.de";
DELETE FROM "providers" WHERE "name"="BitcoinTrade";
DELETE FROM "providers" WHERE "name"="Bitfinex";
DELETE FROM "providers" WHERE "name"="Bitflyer";
DELETE FROM "providers" WHERE "name"="BitGo";
DELETE FROM "providers" WHERE "name"="Bithumb";
DELETE FROM "providers" WHERE "name"="BitMEX";
DELETE FROM "providers" WHERE "name"="Bitpanda";
DELETE FROM "providers" WHERE "name"="Bitpay";
DELETE FROM "providers" WHERE "name"="Bitstamp";
DELETE FROM "providers" WHERE "name"="Bittrex";
DELETE FROM "providers" WHERE "name"="Blockchain";
DELETE FROM "providers" WHERE "name"="BlockFi";
DELETE FROM "providers" WHERE "name"="Braziliex";
DELETE FROM "providers" WHERE "name"="BTC BOX";
DELETE FROM "providers" WHERE "name"="BTC Markets";
DELETE FROM "providers" WHERE "name"="BTCPOP";
DELETE FROM "providers" WHERE "name"="Buda";
DELETE FROM "providers" WHERE "name"="Bybit";
DELETE FROM "providers" WHERE "name"="CEX.IO";
DELETE FROM "providers" WHERE "name"="Changelly";
DELETE FROM "providers" WHERE "name"="Circle";
DELETE FROM "providers" WHERE "name"="Coin Cafe";
DELETE FROM "providers" WHERE "name"="Coinapult";
DELETE FROM "providers" WHERE "name"="Coinbase";
DELETE FROM "providers" WHERE "name"="Coincheck";
DELETE FROM "providers" WHERE "name"="CoinDeal";
DELETE FROM "providers" WHERE "name"="CoinFalcon";
DELETE FROM "providers" WHERE "name"="CoinGate";
DELETE FROM "providers" WHERE "name"="Coinify";
DELETE FROM "providers" WHERE "name"="Coinjar";
DELETE FROM "providers" WHERE "name"="CoinOne";
DELETE FROM "providers" WHERE "name"="Coins.ph";
DELETE FROM "providers" WHERE "name"="Coinspot";
DELETE FROM "providers" WHERE "name"="CoinTracker";
DELETE FROM "providers" WHERE "name"="CoinTracking";
DELETE FROM "providers" WHERE "name"="Coinut";
DELETE FROM "providers" WHERE "name"="Crypto";
DELETE FROM "providers" WHERE "name"="Cryptonator";
DELETE FROM "providers" WHERE "name"="DSX";
DELETE FROM "providers" WHERE "name"="Gatehub";
DELETE FROM "providers" WHERE "name"="HitBTC";
DELETE FROM "providers" WHERE "name"="Invictus Capital";
DELETE FROM "providers" WHERE "name"="Korbit";
DELETE FROM "providers" WHERE "name"="Kraken";
DELETE FROM "providers" WHERE "name"="Kuna";
DELETE FROM "providers" WHERE "name"="Liquid";
DELETE FROM "providers" WHERE "name"="LiteBit";
DELETE FROM "providers" WHERE "name"="LocalBitcoins";
DELETE FROM "providers" WHERE "name"="LocalCryptos";
DELETE FROM "providers" WHERE "name"="Luno";
DELETE FROM "providers" WHERE "name"="MaiCoin";
DELETE FROM "providers" WHERE "name"="Mercado Bitcoin";
DELETE FROM "providers" WHERE "name"="OKEx";
DELETE FROM "providers" WHERE "name"="PayKassa";
DELETE FROM "providers" WHERE "name"="Poloniex";
DELETE FROM "providers" WHERE "name"="Remitano";
DELETE FROM "providers" WHERE "name"="SatoshiTango";
DELETE FROM "providers" WHERE "name"="STEX";
DELETE FROM "providers" WHERE "name"="Uphold";
DELETE FROM "providers" WHERE "name"="ViaBTC";
DELETE FROM "providers" WHERE "name"="Wirex";
DELETE FROM "providers" WHERE "name"="Action Network";
DELETE FROM "providers" WHERE "name"="Airship";
DELETE FROM "providers" WHERE "name"="Basecamp";
DELETE FROM "providers" WHERE "name"="Bitrix24";
DELETE FROM "providers" WHERE "name"="Campfire";
DELETE FROM "providers" WHERE "name"="Capsule";
DELETE FROM "providers" WHERE "name"="Close";
DELETE FROM "providers" WHERE "name"="Cloze";
DELETE FROM "providers" WHERE "name"="Customer.io";
DELETE FROM "providers" WHERE "name"="Direct Mail";
DELETE FROM "providers" WHERE "name"="Discord";
DELETE FROM "providers" WHERE "name"="FAX.PLUS";
DELETE FROM "providers" WHERE "name"="Front App";
DELETE FROM "providers" WHERE "name"="Grape";
DELETE FROM "providers" WHERE "name"="Groups.io";
DELETE FROM "providers" WHERE "name"="Hangouts";
DELETE FROM "providers" WHERE "name"="HubSpot";
DELETE FROM "providers" WHERE "name"="Intercom";
DELETE FROM "providers" WHERE "name"="MailChimp";
DELETE FROM "providers" WHERE "name"="Mailgun";
DELETE FROM "providers" WHERE "name"="Missive App";
DELETE FROM "providers" WHERE "name"="Nulab";
DELETE FROM "providers" WHERE "name"="Postmarkapp";
DELETE FROM "providers" WHERE "name"="Salesforce";
DELETE FROM "providers" WHERE "name"="Skype";
DELETE FROM "providers" WHERE "name"="Slack";
DELETE FROM "providers" WHERE "name"="SocketLabs";
DELETE FROM "providers" WHERE "name"="SparkPost";
DELETE FROM "providers" WHERE "name"="Stackfield";
DELETE FROM "providers" WHERE "name"="Zoom";
DELETE FROM "providers" WHERE "name"="Amazon Web Services";
DELETE FROM "providers" WHERE "name"="Brightbox";
DELETE FROM "providers" WHERE "name"="Cloud 66";
DELETE FROM "providers" WHERE "name"="cloud.ca";
DELETE FROM "providers" WHERE "name"="DigitalOcean";
DELETE FROM "providers" WHERE "name"="Engine Yard";
DELETE FROM "providers" WHERE "name"="Equinix Metal";
DELETE FROM "providers" WHERE "name"="fortrabbit";
DELETE FROM "providers" WHERE "name"="Google Cloud Platform";
DELETE FROM "providers" WHERE "name"="Heroku";
DELETE FROM "providers" WHERE "name"="Hostiso";
DELETE FROM "providers" WHERE "name"="IBM Cloud";
DELETE FROM "providers" WHERE "name"="Jelastic";
DELETE FROM "providers" WHERE "name"="Joyent";
DELETE FROM "providers" WHERE "name"="Laravel Forge";
DELETE FROM "providers" WHERE "name"="Leaseweb";
DELETE FROM "providers" WHERE "name"="Linode";
DELETE FROM "providers" WHERE "name"="MacStadium";
DELETE FROM "providers" WHERE "name"="Microsoft Azure";
DELETE FROM "providers" WHERE "name"="mLab";
DELETE FROM "providers" WHERE "name"="Rackspace";
DELETE FROM "providers" WHERE "name"="Scaleway";
DELETE FROM "providers" WHERE "name"="Scalr";
DELETE FROM "providers" WHERE "name"="Tilaa";
DELETE FROM "providers" WHERE "name"="UpCloud";
DELETE FROM "providers" WHERE "name"="Userify";
DELETE FROM "providers" WHERE "name"="Vultr";
DELETE FROM "providers" WHERE "name"="Betfair";
DELETE FROM "providers" WHERE "name"="Betvictor";
DELETE FROM "providers" WHERE "name"="Cloudbet";
DELETE FROM "providers" WHERE "name"="Smarkets";
DELETE FROM "providers" WHERE "name"="Addiko Bank";
DELETE FROM "providers" WHERE "name"="Avanza";
DELETE FROM "providers" WHERE "name"="Bitwala";
DELETE FROM "providers" WHERE "name"="Woodforest National Bank";
DELETE FROM "providers" WHERE "name"="Backblaze";
DELETE FROM "providers" WHERE "name"="Dropbox";
DELETE FROM "providers" WHERE "name"="Evernote";
DELETE FROM "providers" WHERE "name"="Files.com";
DELETE FROM "providers" WHERE "name"="Google Drive";
DELETE FROM "providers" WHERE "name"="Jottacloud";
DELETE FROM "providers" WHERE "name"="Koofr";
DELETE FROM "providers" WHERE "name"="Mega";
DELETE FROM "providers" WHERE "name"="Nimbox";
DELETE FROM "providers" WHERE "name"="OneDrive";
DELETE FROM "providers" WHERE "name"="PCloud";
DELETE FROM "providers" WHERE "name"="QNAP";
DELETE FROM "providers" WHERE "name"="Sync";
DELETE FROM "providers" WHERE "name"="Synology";
DELETE FROM "providers" WHERE "name"="Tresorit";
DELETE FROM "providers" WHERE "name"="Wasabi";
DELETE FROM "providers" WHERE "name"="Zoolz";
DELETE FROM "providers" WHERE "name"="Battle.net";
DELETE FROM "providers" WHERE "name"="Blizzard";
DELETE FROM "providers" WHERE "name"="Gitea";
