INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AirVPN", "https://airvpn.org/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IVPN", "https://www.ivpn.net/", "https://www.ivpn.net/knowledgebase/232/Do-you-offer-Two-Factor-Authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NordVPN Teams", "https://nordvpnteams.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Private Internet Access", "https://www.privateinternetaccess.com", "https://www.privateinternetaccess.com/helpdesk/kb/articles/how-do-i-enable-and-use-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ProtonVPN", "https://protonvpn.com/", "https://protonvpn.com/support/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Surfshark", "https://surfshark.com/", "https://support.surfshark.com/hc/en-us/articles/360011448319");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TorGuard", "https://torguard.net", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VPN Unlimited", "https://vpnunlimitedapp.com/", "https://www.vpnunlimitedapp.com/help/manuals/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Windscribe", "https://windscribe.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Andrews & Arnold", "https://aa.net.uk", "https://aa.net.uk/kb-broadband-2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Con Edison", "https://www.coned.com/", "https://www.coned.com/-/media/files/coned/documents/small-medium-large-businesses/building-project-center/contractor-resources/user-registration-guide.pdf?la=en");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Fi", "https://fi.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Fiber", "https://fiber.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Republic Wireless", "https://republicwireless.com/", "https://help.republicwireless.com/hc/en-us/articles/360008803994");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sonic", "https://www.sonic.com/", "https://help.sonic.com/hc/en-us/articles/236079387");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("T-Mobile", "https://www.t-mobile.com/", "https://support.t-mobile.com/docs/DOC-2727");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Telzio", "https://www.telzio.com/", "https://telzio.com/support/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ting", "https://ting.com/", "https://help.ting.com/hc/en-us/articles/209351258");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Uber", "https://www.uber.com/", "https://help.uber.com/h/b8bb9152-8c91-4f49-83c4-35cf2e1dcf72");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Airtable", "https://airtable.com", "https://support.airtable.com/hc/en-us/articles/219409917");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Clubhouse", "https://clubhouse.io", "https://help.clubhouse.io/hc/en-us/articles/360044506931");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Meistertask", "https://www.meistertask.com", "https://support.mindmeister.com/hc/en-us/articles/218901367");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Microsoft To-Do", "https://todo.microsoft.com/", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Planio", "https://plan.io", "https://support.plan.io/news/133");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Toodledo", "https://www.toodledo.com", "https://www.toodledo.com/info/help.php#168");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Trello", "https://trello.com", "https://help.trello.com/article/993--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buffer", "https://bufferapp.com", "https://blog.bufferapp.com/introducing-the-safest-social-media-publishing-on-the-web");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Facebook", "https://facebook.com", "https://www.facebook.com/help/148233965247823");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HootSuite", "https://hootsuite.com", "https://help.hootsuite.com/hc/en-us/articles/204595950");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Instagram", "https://www.instagram.com", "https://help.instagram.com/566810106808145");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LinkedIn", "https://linkedin.com", "https://www.linkedin.com/help/linkedin/answer/544");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Lobsters", "https://lobste.rs/", "https://lobste.rs/s/1cyltz/two_factor_authentication_now_available");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Plurk", "https://plurk.com", "https://www.plurk.com/p/mrcii5");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Reddit", "https://www.reddit.com/", "https://www.reddithelp.com/hc/en-us/articles/360043470031");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Restream.io", "https://restream.io/", "https://support.restream.io/en/articles/870429");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Short.io", "https://short.io/", "https://help.short.io/en/articles/4065798");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Snapchat", "https://www.snapchat.com/", "https://support.snapchat.com/en-US/article/enable-login-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tumblr", "https://www.tumblr.com/", "https://www.tumblr.com/docs/en/two_factor_auth");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Twitter", "https://twitter.com", "https://support.twitter.com/articles/20170388");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VK", "https://vk.com", "https://vk.com/page-777107_53677752");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WordPress.com", "https://wordpress.com", "https://en.support.wordpress.com/security/two-step-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wykop", "https://www.wykop.pl", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("XING", "https://www.xing.com", "https://faq.xing.com/en/settings-security/two-factor-login-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AdGuard", "https://adguard.com", "https://kb.adguard.com/en/general/2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitdefender", "https://www.bitdefender.com", "https://www.bitdefender.com/consumer/support/answer/1581/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Blur", "https://www.abine.com/", "https://dnt.abine.com/#help/faq/faq-enabletwoFactor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Boxcryptor", "https://www.boxcryptor.com", "https://www.boxcryptor.com/help/boxcryptor-account/#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("bugcrowd", "https://bugcrowd.com", "https://docs.bugcrowd.com/customers/role-and-account-management/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloudflare", "https://cloudflare.com", "https://support.cloudflare.com/hc/en-us/articles/200167906");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cobalt", "https://cobalt.io/", "https://cobalt.io/blog/new-feature-two-factor-auth/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DigiCert", "https://www.digicert.com/", "https://www.digicert.com/two-factor-authentication.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DMARC Analyzer", "https://www.dmarcanalyzer.com/", "https://www.dmarcanalyzer.com/set-two-factor-authentication-additional-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("dmarcian", "https://dmarcian.com/", "https://dmarcian.com/secure-dmarcian-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dome9 Security", "https://dome9.com/", "https://dome9.com/overview/strong-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("EasyDMARC", "https://easydmarc.com", "https://easydmarc.com/blog/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HackerOne", "https://hackerone.com", "https://docs.hackerone.com/hackers/two-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("intigriti", "https://www.intigriti.com/", "https://kb.intigriti.com/en/articles/2642631");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kaspersky", "https://www.kaspersky.com/", "https://help.kaspersky.com/KPC/1.0/en-US/152628.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Panther", "https://runpanther.io", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Prey", "https://www.preyproject.com", "https://help.preyproject.com/article/248--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pwnie Express Pwn Pulse", "https://www.pwnieexpress.com/products/pulse-device-detection", "http://support.pwnieexpress.com/customer/en/portal/articles/2858909");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RBLTracker", "https://rbltracker.com/", "https://rbltracker.com/docs/setting-up-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sophos Central", "https://www.sophos.com", "https://docs.sophos.com/central/Customer/help/en-us/central/Customer/concepts/ep_MultiFactorAuthentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SSLTrust", "https://www.ssltrust.com.au/", "https://www.ssltrust.com.au/help/account-management/enable-2factor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ThreatConnect", "https://threatconnect.com/", "https://kb.threatconnect.com/customer/en/portal/articles/2214975");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ThreatX", "https://www.threatx.com/", "https://support.threatx.com/hc/en-us/articles/360022157591");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tinfoil Security", "https://www.tinfoilsecurity.com", "https://support.tinfoilsecurity.com/article/43-do-you-support-two-factor-authentication-how-do-i-set-it-up");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VirusTotal", "https://www.virustotal.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Webroot", "https://www.webroot.com", "https://docs.webroot.com/us/en/home/wsa_website_userguide/wsa_managementwebsite_userguide.htm#GettingStarted/Enabling2-FactorAuthentication.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Adafruit", "https://www.adafruit.com", "https://learn.adafruit.com/how-to-set-up-2-factor-authentication-on-adafruit");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Amazon", "https://www.amazon.com", "https://www.amazon.com/gp/help/customer/display.html?nodeId=201962420");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Best Buy", "https://www.bestbuy.com/", "https://www.bestbuy.com/site/help-topics/2-step-verification/pcmcat1561056149844.c");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Digitec", "https://www.digitec.ch", "https://www.digitec.ch/en/page/6589");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Etsy", "https://www.etsy.com/", "https://help.etsy.com/hc/en-us/articles/115015569567");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Migros", "https://www.migros.ch", "https://login.migros.ch/help/security/2fa?hl=en");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Newegg", "https://www.newegg.com", "https://kb.newegg.com/knowledge-base/2-step-verification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Purse", "https://purse.io/", "https://support.purse.io/account/2-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Samsung", "https://www.samsung.com/", "https://account.samsung.com/membership/guide/2step/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Shopify", "https://shopify.com/", "https://help.shopify.com/manual/your-account/account-security/two-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tokopedia", "https://www.tokopedia.com/", "https://www.tokopedia.com/panduan-keamanan/fitur-keamanan-tambahan/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AnyDesk", "https://anydesk.com/", "https://support.anydesk.com/Two-Factor_Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ConnectWise Control (ScreenConnect)", "https://www.connectwise.com/software/control", "https://docs.connectwise.com/ConnectWise_Control_Documentation/Get_started/Administration_page/Security_page/Enable_two-factor_authentication_for_host_accounts");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DirectAdmin", "https://www.directadmin.com", "https://directadmin.com/features.php?id=1754");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ISL Online", "https://islonline.com/", "https://help.islonline.com/35746/286527");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("join.me (w/ LogMeIn account)", "https://join.me/", "https://support.logmeininc.com/pro/help#logmein-t-login-policy-set-twofactor-ownaccount");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LogMeIn", "https://www.logmein.com/", "https://support.logmeininc.com/pro/help#logmein-t-login-policy-set-twofactor-ownaccount");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MB Connect Line", "https://www.mbconnectline.com", "http://www.cc-onlinehelp.com/en/#index/administrati/users/authenticati/authenticati.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("O&O Syspectr", "https://www.syspectr.com", "https://www.syspectr.com/en/faq/how-do-i-activate-deactivate-two-factor-authentication-for-my-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RealVNC", "https://www.realvnc.com", "https://help.realvnc.com/hc/en-us/articles/360003110878");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Remote Desktop Manager", "https://www.remotedesktopmanager.com", "https://help.remotedesktopmanager.com/howto_googleauthenticator.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TeamViewer", "https://www.teamviewer.com", "https://www.teamviewer.com/en/help/402-How-do-I-activate-deactivate-two-factor-authentication-for-my-TeamViewer-account.aspx");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Amazon Pay", "https://pay.amazon.com", "https://www.amazon.com/gp/help/customer/display.html?nodeId=201962420");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AppFolio", "https://www.appfolio.com/", "https://www.appfolio.com/help/online-portal");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Braintree", "https://www.braintreepayments.com/", "https://articles.braintreepayments.com/reference/security/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Chargebee", "https://www.chargebee.com/", "https://www.chargebee.com/docs/2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dwolla", "https://www.dwolla.com", "https://www.dwolla.com/updates/introducing-two-factor-authentication-for-dwolla/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GoCardless", "https://gocardless.com/", "https://support.gocardless.com/hc/en-gb/articles/360001164385");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Pay", "https://pay.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NETELLER", "https://www.neteller.com/", "https://www.neteller.com/en/support#/path/ACCOUNT/Two-Factor-Authentication/85238429");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PayPal", "https://www.paypal.com/", "https://www.paypal.com/us/smarthelp/article/faq4057");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Paysafecard", "https://www.paysafecard.com/", "https://www.paysafecard.com/en-au/lp-products/2-step-login/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Privacy", "https://privacy.com/", "https://support.privacy.com/hc/en-us/articles/360012047174");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ravelin", "https://www.ravelin.com/", "https://ravelin.zendesk.com/hc/en-us/articles/115001071665");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Skrill", "https://skrill.com", "https://skrill.com/en-us/support#/path/ACCOUNT/Two-Factor-Authentication/905782552/Two-Factor-Authentication-2FA.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Square", "https://squareup.com", "https://squareup.com/help/us/en/article/5593");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Stripe", "https://www.stripe.com/", "https://support.stripe.com/questions/how-do-i-enable-two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tebex", "https://www.tebex.io/", "https://help.tebex.io/en/articles/2319372");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WePay", "https://go.wepay.com", "https://support.wepay.com/hc/en-us/articles/203609693");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Yandex.Money", "https://money.yandex.ru", "https://money.yandex.ru/doc.xml?id=524852");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Adobe ID", "https://adobe.com/", "https://helpx.adobe.com/manage-account/using/secure-your-adobe-account.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AngelList", "https://angel.co", "https://angel.co/projects/106166");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Autodesk", "https://www.autodesk.com", "https://knowledge.autodesk.com/customer-service/account-management/account-profile/account-security/two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Automater", "https://automater.pl/en/", "https://help.automater.com/help/two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AwardWallet", "https://awardwallet.com", "https://awardwallet.com/faqs#44");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Basic Attention Token", "https://publishers.basicattentiontoken.org/", "https://support.brave.com/hc/en-us/articles/360021649491");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CharlieHR", "https://charliehr.com/", "https://intercom.help/charliehr/en/articles/1037152");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Chartbeat", "https://chartbeat.com/", "https://chartbeat.zendesk.com/hc/en-us/articles/209531888");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cisco Meraki", "https://meraki.cisco.com/", "https://documentation.meraki.com/zGeneral_Administration/Managing_Dashboard_Access/Using_Google_Authenticator_for_Two-factor_Authentication_in_Dashboard");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CloudConvert", "https://cloudconvert.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloudinary", "https://cloudinary.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Contentful", "https://www.contentful.com/", "https://www.contentful.com/faq/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Envato", "https://envato.com", "https://help.market.envato.com/hc/en-us/articles/115005592963");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Figma", "https://www.figma.com/", "https://help.figma.com/hc/en-us/articles/360039817634");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Findmyshift", "https://www.findmyshift.com/", "https://www.findmyshift.com/help/what-is-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Firefox", "https://accounts.firefox.com", "https://support.mozilla.org/en-US/kb/secure-firefox-account-two-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Formstack", "https://www.formstack.com/", "https://help.formstack.com/hc/en-us/articles/360019517891");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Grammarly", "https://grammarly.com/", "https://support.grammarly.com/hc/en-us/articles/360032922091");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GrowingIO", "https://www.growingio.com/", "https://docs.growingio.com/docs/product-manual/sysmanage/personal/security#kai-qi-er-ci-yan-zheng");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Help Scout", "https://helpscout.com", "https://docs.helpscout.com/article/907--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ImmobilienScout24", "https://www.immobilienscout24.de", "https://www.youtube.com/watch?v=37Tgxy3NoG4");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Jitbit Helpdesk", "https://www.jitbit.com/hosted-helpdesk/", "https://support.jitbit.com/helpdesk/KB/View/11048235");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kayako", "https://www.kayako.com", "https://help.kayako.com/hc/en-us/articles/360006376420");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kickstarter", "https://www.kickstarter.com", "https://help.kickstarter.com/hc/en-us/articles/115005127094");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MathWorks", "https://www.mathworks.com/", "https://www.mathworks.com/mw_account/two_step_verification/frequently-asked-questions.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("No Starch Press", "https://nostarch.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Office 365", "https://office.microsoft.com/en-us/business/", "https://support.office.com/en-US/article/Set-up-multi-factor-authentication-for-Office-365-8f0454b2-f51a-4d9c-bcde-2c48e41621c6");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Onshape", "https://www.onshape.com/", "https://cad.onshape.com/help/Content/twofactorauthentication.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Opera", "https://auth.opera.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Patreon", "https://www.patreon.com/", "https://support.patreon.com/hc/en-us/articles/206538086");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PhraseApp", "https://phraseapp.com", "https://phraseapp.com/blog/posts/multi-factor-how-to-secure-your-account-using-multi-factor/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Repairshopr", "https://www.repairshopr.com/", "https://feedback.repairshopr.com/knowledgebase/articles/928266");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ripe NCC", "https://www.ripe.net/", "https://www.ripe.net/participate/member-support/ripe-ncc-access/two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SaneBox", "https://www.sanebox.com/", "https://www.sanebox.com/help/127");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SmartSimple", "https://www.smartsimple.com", "https://wiki.smartsimple.com/wiki/Two-Factor_Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Teespring", "https://teespring.com", "https://community.teespring.com/blog/a-more-secure-teespring-two-factor-authentification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ubiquiti Inc", "https://www.ui.com", "https://help.ubnt.com/hc/en-us/articles/115012986607");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Upwork", "https://www.upwork.com", "https://support.upwork.com/hc/en-us/articles/360009491414");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Usabilla", "https://usabilla.com", "https://support.usabilla.com/hc/en-us/articles/115003081611");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Watchman Monitoring", "https://www.watchmanmonitoring.com", "https://support.watchmanmonitoring.com/hc/en-us/articles/205004059");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Weclapp", "https://weclapp.com/", "https://doc.weclapp.com/knowledgebase/zwei-wege-authentifizierung-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wikipedia", "https://www.wikipedia.org/", "https://meta.wikimedia.org/wiki/Help:Two-factor_authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Yclas", "https://yclas.com/", "https://docs.yclas.com/2-step-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("YourAcclaim", "https://youracclaim.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zendesk", "https://www.zendesk.com", "https://support.zendesk.com/hc/en-us/articles/206373587");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Clio", "https://www.clio.com", "https://support.clio.com/hc/en-us/articles/203184210");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Docusign", "https://www.docusign.com", "https://support.docusign.com/en/guides/ndse-user-guide-two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Everlaw", "https://everlaw.com", "https://support.everlaw.com/hc/en-us/articles/206312165");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HelloSign", "https://www.hellosign.com/", "https://faq.hellosign.com/hc/en-us/articles/360025164091");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ecobee", "https://ecobee.com", "https://support.ecobee.com/hc/en-us/articles/360040957212");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IFTTT", "https://ifttt.com", "https://help.ifttt.com/hc/en-us/articles/115010193007");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Samsung SmartThings", "https://www.smartthings.com/", "https://account.samsung.com/membership/guide/2step/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tesla", "https://www.tesla.com", "https://www.tesla.com/support/multi-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AJ Bell Youinvest", "https://www.youinvest.co.uk/", "https://www.youinvest.co.uk/faq/how-do-i-set-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Betterment", "https://www.betterment.com/", "https://www.betterment.com/resources/understanding-account-security/#3");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mintos", "https://www.mintos.com/", "https://help.mintos.com/hc/en-us/sections/360000373858");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nutmeg", "https://www.nutmeg.com/", "https://support.nutmeg.com/hc/en-us?article=115000495111-How-to-set-up-and-manage-2-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Robinhood", "https://www.robinhood.com/", "https://support.robinhood.com/hc/en-us/articles/360001213783");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SelfWealth", "https://www.selfwealth.com.au/", "https://www.selfwealth.com.au/two-factor-authentication-now-available/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wealthfront", "https://www.wealthfront.com/", "https://support.wealthfront.com/hc/en-us/articles/211004563");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wealthsimple", "https://www.wealthsimple.com", "https://help.wealthsimple.com/hc/en-ca/articles/360005175373");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("1Password", "https://1password.com/", "https://support.1password.com/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("bitwarden", "https://bitwarden.com", "https://help.bitwarden.com/article/setup-two-step-login/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Centrify", "https://www.centrify.com", "https://www.centrify.com/pam/authentication-service/mfa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dashlane", "https://www.dashlane.com", "https://support.dashlane.com/hc/en-us/articles/202625042");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ID.me", "https://www.id.me/", "https://help.id.me/hc/en-us/categories/360001435974");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Keeper", "https://keepersecurity.com/", "https://www.keepersecurity.com/security#twoFactor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LastPass", "https://lastpass.com/", "https://support.logmeininc.com/lastpass/help/enable-multifactor-authentication-lp010002");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NordPass", "https://nordpass.com/", "https://support.nordpass.com/hc/en-us/articles/360002770497-How-to-enable-Two-Factor-Authentication-");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Okta", "https://www.okta.com/", "https://help.okta.com/en/prod/Content/Topics/Security/MFA.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OneLogin", "https://www.onelogin.com/", "https://onelogin.service-now.com/support?id=kb_article&sys_id=43d99143db109700d5505eea4b96197a");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ORCID", "https://orcid.org/", "https://support.orcid.org/hc/en-us/articles/360006971673");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Passwarden", "https://www.keepsolid.com/passwarden/", "https://www.keepsolid.com/passwarden/security/tfa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RoboForm", "https://www.roboform.com/", "https://help.roboform.com/hc/en-us/articles/115002729512");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("20i", "https://www.20i.com", "https://www.20i.com/support/my-services/two-factor-authentication-my20i");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("34SP.com", "https://www.34SP.com", "https://www.34sp.com/kb/142/how-to-enable-two-factor-authentication-on-your-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("A2 Hosting", "https://www.a2hosting.com", "https://www.a2hosting.com/kb/a2-hosting-customer-portal/account-management/enabling-two-factor-authentication-for-your-a2-hosting-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Acquia", "https://www.acquia.com", "https://docs.acquia.com/acquia-cloud/access/signin/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ACTIVE 24", "https://www.active24.com/", "https://faq.active24.com/cz/183996-");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ALL-INKL.COM", "https://all-inkl.com/", "https://all-inkl.com/wichtig/faq/#2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Binary Lane", "https://www.binarylane.com.au/", "https://www.binarylane.com.au/support/solutions/articles/1000199372");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Binero", "https://www.binero.se", "https://blogg.binero.se/2017/10/tvafaktorsautentisering/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Blacknight", "https://blacknight.com", "https://help.blacknight.com/hc/en-us/articles/360001358517");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bluehost", "https://www.bluehost.com/", "https://my.bluehost.com/cgi/help/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BunnyCDN", "https://bunnycdn.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Carrd", "https://carrd.co/", "https://carrd.co/docs/account/enabling-google-authenticator");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CDN77", "https://www.cdn77.com", "https://client.cdn77.com/support/knowledgebase/billing/cdn77-two-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CDNsun", "https://cdnsun.com", "https://cdnsun.com/knowledgebase/billing/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloudways", "https://www.cloudways.com/", "https://support.cloudways.com/enabling-two-factor-authentication-for-your-cloudways-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Contabo", "https://contabo.com/", "https://contabo.com/?show=faq#100");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("cyon", "https://www.cyon.ch", "https://www.cyon.ch/support/a/zwei-schritt-verifizierung-aktivieren");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dreamhost", "https://dreamhost.com", "https://help.dreamhost.com/hc/en-us/articles/216013897");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Easy", "https://easy.gr/", "https://easy.gr/el/faq");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fastly", "https://www.fastly.com", "https://docs.fastly.com/guides/account-management-and-security/enabling-and-disabling-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Flywheel", "https://getflywheel.com", "https://getflywheel.com/wordpress-support/how-to-enable-two-factor-authentication-on-flywheel");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Glesys", "https://glesys.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Greenhost", "https://greenhost.net", "https://greenhost.net/blog/2016/03/01/spring-news-2-factor-authentication-service-center-haproxy-plugin-for-let-s-encrypt-and-more/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hetzner Online", "https://www.hetzner.de/", "https://wiki.hetzner.de/index.php/KonsoleH:Zwei-Faktor-Authentifizierung/en");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostens", "https://www.hostens.com/", "https://www.hostens.com/knowledgebase/how-to-enhance-account-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostpoint", "https://www.hostpoint.ch/", "https://support.hostpoint.ch/en/administrative/hostpoint-id/general-questions-about-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HostUS", "https://hostus.us", "https://my.hostus.us/knowledgebase/106");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ICDSoft", "https://www.icdsoft.com", "https://tickets.suresupport.com/faq/article-1700");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ICUK", "https://www.icuk.net", "https://www.icuk.net/reseller/security.asp");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Infomaniak", "https://www.infomaniak.com/", "https://www.infomaniak.ch/en/support/faq/1940");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("INIZ", "https://iniz.com", "https://my.iniz.com/knowledgebase/51");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IO Zoom", "https://www.iozoom.com", "https://www.iozoom.com/client/announcements.php?id=6");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("KnownHost", "https://www.knownhost.com", "https://www.knownhost.com/wiki/my-knownhost/two-factor");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Liquid Web", "https://www.liquidweb.com", "https://www.liquidweb.com/kb/how-to-enable-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mammoth Networks", "https://www.mammoth.net.au/", "https://www.mammoth.net.au/news/2012/10/22/two-factor-authentication-now-available");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Miss Hosting", "https://misshosting.com/", "https://github.com/2factorauth/twofactorauth/issues/3634#issuecomment-454688629");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NearlyFreeSpeech.NET", "https://www.nearlyfreespeech.net/", "https://blog.nearlyfreespeech.net/2014/02/28/price-cuts-more-security-and-recovery-options/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Neolo", "https://www.neolo.com", "https://ar.neolo.com/knowledgebase/215/Autenticacion-de-2-factores.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Netcup", "https://netcup.eu/", "https://www.netcup-wiki.de/wiki/Stammdaten_CCP#Zwei-Faktor-Authentifizierung_.282FA.29");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Netlify", "https://www.netlify.com", "https://docs.netlify.com/accounts-and-billing/user-settings/#two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nitrado", "https://server.nitrado.net/", "https://server.nitrado.net/deu/news2/view/nitrado-bietet-zweifaktorauthentifizierung/?f=index/mode:0/page:2");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Noez", "https://noez.de/", "https://noez.de/en/faq/post/199/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Oderland", "https://www.oderland.se/", "https://www.oderland.se/support/en/artikel/how-is-my-personal-information-handled/#how-do-i-encrypt-personal-information");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OMGServ", "https://www.omgserv.com", "https://www.omgserv.com/fr/faq-site/comment_activer_la_double_authentification-103/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Online", "https://www.online.net/", "https://documentation.online.net/en/account-management/account/enable-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OVH", "https://www.ovh.com/", "https://docs.ovh.com/gb/en/customer/secure-account-with-2FA/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PlanetHoster", "https://www.planethoster.com/", "https://blog.planethoster.com/securite-espace-client-planethoster/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RamNode", "https://www.ramnode.com", "https://clientarea.ramnode.com/knowledgebase.php?action=displayarticle&id=4129");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RunCloud", "https://www.runcloud.io", "https://runcloud.io/docs/account/authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("section.io", "https://www.section.io", "https://www.section.io/docs/how-to/user-management/enable-two-factor-authentication-on-your-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Segment", "https://segment.com/", "https://segment.com/docs/iam/mfa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SiteGround", "https://www.siteground.com", "https://www.siteground.com/tutorials/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Squarespace", "https://squarespace.com/", "https://support.squarespace.com/hc/en-us/articles/360000044827");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("StackPath", "https://www.stackpath.com", "https://support.stackpath.com/hc/en-us/articles/360022992631");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Time4VPS", "https://www.time4vps.eu/", "https://billing.time4vps.eu/knowledgebase/article/100/2-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("TransIP", "https://www.transip.nl/", "https://www.transip.nl/knowledgebase/artikel/162");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("UKFast", "https://www.ukfast.co.uk/", "https://github.com/2factorauth/twofactorauth/pull/997#issuecomment-77708501");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ukraine", "https://www.ukraine.com.ua/", "https://www.ukraine.com.ua/faq/rekomendatsii-po-zashchite-ot-vzloma-uchetnoj-zapisi.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("UpCloud", "https://www.upcloud.com", "https://www.upcloud.com/support/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VentraIP", "https://ventraip.com.au", "https://ventraip.com.au/faq/article/two-factor-authentication-faq-vipcontrol/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Versio", "https://www.versio.nl", "https://www.versio.nl/nieuws/twofactor-authenticatie-nu-beschikbaar-voor-uw-klantenaccount-205");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VPS Server", "https://www.vpsserver.com/", "https://github.com/2factorauth/twofactorauth/pull/2311#issuecomment-273424695");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WebFaction", "https://www.webfaction.com", "https://docs.webfaction.com/user-guide/control_panel.html#two-step-login");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Webflow", "https://webflow.com/", "https://university.webflow.com/lesson/two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wedos", "https://hosting.wedos.com", "https://kb.wedos.com/cs/zakaznik/otp.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("World4You", "https://www.world4you.com", "https://www.world4you.com/faq/en/w4y-app/faq.zwei-faktor-authentifizierung-world4you-app.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("WP Engine", "https://wpengine.com/", "https://wpengine.com/support/2-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("23andMe", "https://www.23andme.com/", "https://customercare.23andme.com/hc/en-us/articles/360034119874");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cronometer", "https://cronometer.com/", "https://cronometer.zendesk.com/hc/en-us/articles/360042096672");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FollowMyHealth", "https://www.followmyhealth.com/", "https://support.followmyhealth.com/2020/03/10/turning-on-two-factor-authentication-while-logged-into-your-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Fit", "https://fit.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hint Health", "https://www.hint.com", "https://support.hint.com/support/solutions/articles/61000283118");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MyHeritage", "https://www.myheritage.com/", "https://www.myheritage.com/help-center/en/article/how-do-i-set-up-two-factor-authentication-for-my-myheritage-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RunSignUp", "https://runsignup.com/", "https://runsignup.blog/2018/09/06/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("login.gov", "https://login.gov/", "https://www.login.gov/help/creating-an-account/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RealMe", "https://www.realme.govt.nz/", "https://www.realme.govt.nz/help/#second-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("US Citizenship and Immigration Services", "https://uscis.gov/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ashes of Creation", "https://ashesofcreation.com", "https://ashesofcreation.zendesk.com/hc/en-us/articles/360022983234");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Aternos", "https://aternos.org/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bethesda", "https://bethesda.net/", "https://help.bethesda.net/app/answers/detail/a_id/48931");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Black Desert Online", "https://www.blackdesertonline.com/", "https://blackdesert.zendesk.com/hc/en-us/articles/360000535909");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Blade & Soul", "https://www.bladeandsoul.com/", "https://support.bladeandsoul.com/hc/en-us/articles/207578553");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bohemia Interactive", "https://www.bohemia.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Call Of Duty", "https://callofduty.com", "https://profile.callofduty.com/cod/announcement2FA");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Electronic Arts (Origin)", "https://www.ea.com/", "https://help.ea.com/en-us/help/account/origin-login-verification-information/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Epic Games", "https://www.epicgames.com/", "https://www.epicgames.com/help/en-US/c74/c112/a3218");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ESL", "https://www.eslgaming.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("EVE Online", "https://www.eveonline.com/", "https://support.eveonline.com/hc/en-us/articles/203465601");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FaceIT", "https://www.faceit.com", "https://support.faceit.com/hc/en-us/articles/115000254670");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fanatical", "https://www.fanatical.com", "https://support.fanatical.com/hc/en-us/articles/360002761397");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gaijin Entertainment", "https://gaijin.net", "https://support.gaijin.net/hc/en-us/articles/203623622");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GREE", "https://product.gree.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Guild Wars 2", "https://www.guildwars2.com", "https://help.guildwars2.com/hc/en-us/articles/230672927");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Humble Bundle", "https://www.humblebundle.com/", "https://support.humblebundle.com/hc/en-us/articles/202421374");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("itch.io", "https://itch.io/", "https://itch.io/docs/advanced/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("lichess.org", "https://lichess.org", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nexon", "https://www.nexon.com", "https://support.nexon.net/hc/en-us/articles/360025920992");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nexus Mods", "https://www.nexusmods.com/", "https://help.nexusmods.com/article/74--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nintendo Account", "https://accounts.nintendo.com/", "https://en-americas-support.nintendo.com/app/answers/detail/a_id/27496");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Parsec", "https://www.parsecgaming.com", "https://support.parsecgaming.com/hc/en-us/articles/360015480691");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Playstation Network", "https://www.playstation.com/", "https://playstation.com/support/2sv/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Razer", "https://www.razer.com/", "https://mysupport.razer.com/app/answers/detail/a_id/1716");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Roberts Space Industries", "https://robertsspaceindustries.com/", "https://support.robertsspaceindustries.com/hc/en-us/articles/115009965628");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rockstar Games Social Club", "https://socialclub.rockstargames.com", "https://support.rockstargames.com/articles/360000031747");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RuneScape", "https://www.runescape.com/", "https://support.runescape.com/hc/en-gb/articles/206811835");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Scryfall", "https://www.scryfall.com/", "https://scryfall.com/docs/privacy#scryfall-accounts");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tibia", "https://www.tibia.com/", "https://www.tibia.com/support/?subtopic=gethelp&topicid=21");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Toontown Rewritten", "https://www.toontownrewritten.com/", "https://www.toontownrewritten.com/help/faq/accounts--login#twostep");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ubisoft/Uplay", "https://uplay.ubi.com/", "https://support.ubi.com/en-GB/Faqs/000039953");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wargaming", "https://wargaming.net/", "https://eu.wargaming.net/support/en/products/wot/article/10568/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Xbox Live", "https://www.xbox.com/live", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("YoYo Games", "https://www.yoyogames.com/", "https://github.com/2factorauth/twofactorauth/pull/4435#issuecomment-566448568");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AltoIRA", "https://www.altoira.com", "https://help.altoira.com/enabling-/-disabling-two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BGL Corporate Solutions", "https://www.bglcorp.com/", "https://sf360.zendesk.com/hc/en-au/articles/360020963051");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitbond", "https://www.bitbond.com", "https://github.com/2factorauth/twofactorauth/pull/2181#issuecomment-266315173");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Carta", "https://carta.com/", "https://support.carta.com/s/article/2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DEGIRO", "https://www.degiro.nl", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Exact Online", "https://exact.com/", "https://support.exactonline.com/community/s/knowledge-base#All-All-HNO-Task-general-security-gen-auth-totpregphndsktpt");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Expensify", "https://www.expensify.com/", "https://community.expensify.com/discussion/7385");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FreeAgent", "https://www.freeagent.com", "https://www.freeagent.com/support/kb/getting-started/two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FreeTaxUSA", "https://www.freetaxusa.com/", "https://www.freetaxusa.com/faqsearch?search_keyword=authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gusto", "https://www.gusto.com", "https://support.gusto.com/1066223171");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("H&R Block", "https://www.hrblock.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Intuit TurboTax", "https://turbotax.intuit.com/", "https://ttlc.intuit.com/questions/2902682");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Justworks", "https://justworks.com/", "https://help.justworks.com/hc/en-us/articles/360004477492");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Metorik", "https://www.metorik.com", "https://help.metorik.com/article/22-how-can-i-enable-2fa-on-my-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mint", "https://www.mint.com", "https://help.mint.com/Security/908045661");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Moneybird", "https://www.moneybird.com/", "https://www.moneybird.nl/blog/twee-staps-verificatie/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Northwestern Mutual", "https://www.northwesternmutual.com/", "https://www.northwesternmutual.com/security-and-privacy/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pocketsmith", "https://www.pocketsmith.com", "https://learn.pocketsmith.com/article/167--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Principal", "https://www.principal.com", "https://secure02.principal.com/publicvsupply/GetFile?fm=ww42&ty=VOP&EXT=.VOP");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Quickbooks Online", "https://quickbooks.intuit.com/", "https://accounts-help.lc.intuit.com/questions/1590157");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("QuickFile", "https://www.quickfile.co.uk", "https://community.quickfile.co.uk/t/2-factor-authentication/8892");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SimpleTax", "https://simpletax.ca/", "https://help.simpletax.ca/questions/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Taxact", "https://www.taxact.com", "https://www.taxact.com/support/24138/2019/how-is-a-verification-code-used?hideLayout=True");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Xero", "https://www.xero.com/", "https://help.xero.com/nz/MyXero_Two-Step_About");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("You Need A Budget (YNAB)", "https://www.youneedabudget.com/", "https://docs.youneedabudget.com/article/1364--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Floatplane", "https://www.floatplane.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Play", "https://play.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Niconico", "https://www.nicovideo.jp/", "https://qa.nicovideo.jp/faq/show/4500");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Plex", "https://www.plex.tv", "https://support.plex.tv/articles/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rocket Beans TV", "https://rocketbeans.tv/", "https://forum.rocketbeans.tv/t/35407/31");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("smashcast", "https://www.smashcast.tv/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Twitch", "https://www.twitch.tv/", "https://help.twitch.tv/s/article/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("YouTube", "https://www.youtube.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FastMail", "https://www.fastmail.com/", "https://www.fastmail.com/help/account/2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gmail", "https://mail.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GMX.net", "https://www.gmx.net/", "https://hilfe.gmx.net/sicherheit/2fa/einrichten.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HEY", "https://hey.com/", "https://hey.com/security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hushmail", "https://www.hushmail.com", "https://help.hushmail.com/hc/en-us/articles/213268943");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("mail.de", "https://mail.de/", "https://mail.de/hilfe/u2f-authenticator");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("mailbox.org", "https://mailbox.org/", "https://kb.mailbox.org/x/5AcS");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mailfence", "https://mailfence.com/", "https://mailfence.com/c/mailfence/more/totp.jsp");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Migadu", "https://www.migadu.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mimecast", "https://www.mimecast.com/", "https://community.mimecast.com/docs/DOC-1915");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Outlook.com", "https://outlook.com", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pobox", "https://www.pobox.com/", "https://pobox.com/helpspot/index.php?pg=kb.chapter&id=65");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Posteo", "https://posteo.de/", "https://posteo.de/en/help/what-is-two-factor-authentication-and-how-do-i-set-it-up");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ProtonMail", "https://protonmail.com/", "https://protonmail.com/support/knowledge-base/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Runbox", "https://runbox.com", "https://help.runbox.com/account-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("StartMail", "https://www.startmail.com", "https://support.startmail.com/hc/en-us/articles/360006682158");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Thexyz", "https://www.thexyz.com/", "https://www.thexyz.com/account/knowledgebase/15/Enabling-two-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tutanota", "https://tutanota.com/", "https://tutanota.com/howto/#2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Web.de", "https://web.de", "https://hilfe.web.de/sicherheit/2fa/index.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Yahoo Japan Mail", "https://mail.yahoo.co.jp/", "https://id.yahoo.co.jp/security/otp.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Yandex.Mail", "https://mail.yandex.com/", "https://yandex.com/support/passport/authorization/twofa.xml");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zimbra", "https://www.zimbra.com/", "https://blog.zimbra.com/2016/02/zimbra-collaboration-8-7-two-factor-authentication-2fa-technical-preview/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zoho Mail", "https://www.zoho.com/mail/", "https://help.zoho.com/portal/kb/articles/mfa-introduction");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("(ISC)2", "https://www.isc2.org", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("East Carolina University", "https://www.ecu.edu", "https://ecu.teamdynamix.com/TDClient/1409/Portal/Requests/ServiceDet?ID=31556");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("itslearning", "https://itslearning.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Karlsruher Institut für Technologie", "https://www.kit.edu", "https://www.scc.kit.edu/dienste/2fa.php");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("KnowBe4", "https://www.knowbe4.com/", "https://support.knowbe4.com/hc/en-us/articles/225681448");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("McGill University", "https://mcgill.ca/", "http://kb.mcgill.ca/#artId:7948");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("North Carolina State University", "https://ncsu.edu", "https://oit.ncsu.edu/it-security/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Philipps-Universität Marburg", "https://www.uni-marburg.de/", "https://www.uni-marburg.de/de/hrz/dienste/2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pluralsight", "https://www.pluralsight.com", "https://help.pluralsight.com/help/multifactor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Ryerson University", "https://www.ryerson.ca", "https://www.ryerson.ca/ccs/services/ITSecurity/protecting-your-identity/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("University of Delaware", "https://www.udel.edu/", "https://www1.udel.edu/it/help/2fa/main.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("007Names", "https://www.007names.com", "https://www.007names.com/info/two-step.xhtml");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("1&1 IONOS", "https://www.ionos.com/", "https://www.ionos.com/help/index.php?id=3269");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("101domain", "https://101domain.com", "https://help.101domain.com/account-management/account-security/enabling-disabling-two-factor-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Above.com", "https://www.above.com", "https://www.above.com/manual/my-account-manual-two-step-auth.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ClouDNS", "https://www.cloudns.net/", "https://www.cloudns.net/wiki/article/201/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Directnic", "https://directnic.com", "https://directnic.com/knowledge/article/137");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DNS Made Easy", "https://www.dnsmadeeasy.com", "https://support.dnsmadeeasy.com/support/solutions/articles/47001001027-enable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DNSimple", "https://dnsimple.com/", "https://support.dnsimple.com/articles/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Domeneshop", "https://domeneshop.no/", "https://domeneshop.no/faq?id=344");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dyn", "https://dyn.com/", "https://help.dyn.com/2-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dynadot", "https://dynadot.com/", "https://dynadot.com/domain/security.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dynu", "https://www.dynu.com/", "https://www.dynu.com/en-US/Blog/Article?Article=It-is-time-to-enable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("easyDNS", "https://easydns.com", "https://kb.easydns.com/knowledge/account-security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("eNom", "https://www.enom.com/", "https://www.enom.com/kb/kb/kb_1687-setup-2-factor.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("EuroDNS", "https://www.eurodns.com", "https://help.eurodns.com/s/article/how-do-i-activate-two-step-verification-on-my-account");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fabulous", "https://fabulous.com", "https://fabulous.com/knowledge/article/137");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Fasthosts", "https://www.fasthosts.co.uk/", "https://help.fasthosts.co.uk/app/answers/detail/a_id/3345");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gandi", "https://gandi.net", "https://docs.gandi.net/en/account_management/security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GoDaddy", "https://www.godaddy.com/", "https://www.godaddy.com/help/enable-two-step-verification-7502");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Domains", "https://domains.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hexonet", "https://www.hexonet.net/", "https://www.hexonet.net/assets/pdf/2FA.pdf");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hover.com", "https://www.hover.com/", "https://help.hover.com/hc/en-us/articles/217282267");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hurricane Electric", "https://www.he.net/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Imperva", "https://www.imperva.com/", "https://docs.imperva.com/bundle/cloud-application-security/page/settings/account-settings.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Internet.bs", "https://www.internet.bs", "/notes/internetbs/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("INWX", "https://www.inwx.com/en/", "https://www.inwx.com/en/offer/mobiletan");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Joker.com", "https://joker.com", "https://joker.com/faq/content/52/480/en/what-is-two_factor_authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Moniker", "https://www.moniker.com/", "https://faq.moniker.com/login-into-moniker");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Name.com", "https://www.name.com/", "https://www.name.com/support/categories/200296798");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Namecheap", "https://www.namecheap.com/", "https://www.namecheap.com/security/2fa-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Namesco", "https://www.names.co.uk/", "https://www.names.co.uk/support/3011.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NameSilo.com", "https://www.namesilo.com/", "https://www.namesilo.com/Support/2~Factor-Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NearlyFreeSpeech.net", "https://www.nearlyfreespeech.net/", "https://blog.nearlyfreespeech.net/2014/02/28/price-cuts-more-security-and-recovery-options/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nominet", "https://www.nominet.uk/", "https://registrars.nominet.uk/gtlds/onboarding-account-management/your-account/account-security-2/two-factor-authentication-user-guide-2/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NS1", "https://ns1.com/", "https://ns1.com/articles/enabling-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OpenDNS", "https://www.opendns.com/", "https://umbrella.cisco.com/blog/2014/05/22/launching-two-step-verification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Openprovider", "https://www.openprovider.co.uk", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OpenSRS", "https://opensrs.com", "https://help.opensrs.com/hc/en-us/articles/360009702113-Using-two-factor-authentication-in-webmail");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("pair Domains", "https://www.pairdomains.com/", "https://www.pairdomains.com/kb/posts/345");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Porkbun", "https://porkbun.com", "https://kb.porkbun.com/category/20--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rebrandly", "https://rebrandly.com", "https://support.rebrandly.com/hc/en-us/articles/360007220373");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Register4Less", "https://register4less.com/", "https://blog.register4less.com/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Registro.br", "https://registro.br", "https://registro.br/ajuda/gerenciamento-de-conta/token/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Synergy Wholesale", "https://synergywholesale.com/", "https://synergywholesale.com/faq/article/can-i-enable-two-factor-authentication-on-my-wholesale-system-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("UK2", "https://www.uk2.net/", "https://github.com/2factorauth/twofactorauth/pull/3845#issuecomment-491518360");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Uniregistry", "https://uniregistry.com/", "https://uniregistry.help/my-account-en/what-is-two-step-verification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("United Domains USA", "https://www.uniteddomains.com/", "https://help.uniteddomains.com/hc/en-us/articles/115001458813");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("united-domains Reselling", "https://www.ud-reselling.com/en/", "https://www.ud-reselling.com/en/security/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("united-domains.de", "https://www.united-domains.de/", "https://help.united-domains.de/faq-article/wie-aktiviere-ich-die-zweistufige-verifizierung-und-mache-mein-portfolio-login-sicherer");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("VentraIP", "https://ventraip.com.au/", "https://ventraip.com.au/faq/article/two-factor-authentication-faq-vipcontrol/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ActiveState", "https://www.activestate.com", "https://docs.activestate.com/platform/prefs/twofactor.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Airbrake", "https://airbrake.io", "https://airbrake.io/docs/features/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Algolia", "https://algolia.com", "https://www.algolia.com/doc/security/best-security-practices/#two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AppSignal", "https://appsignal.com", "https://docs.appsignal.com/user-account/two-factor-authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AppVeyor", "https://www.appveyor.com", "https://www.appveyor.com/blog/2018/11/07/2FA-implementation/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("aTech Media", "https://atechmedia.com", "https://www.deployhq.com/support/managing-your-account/personal-profile/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Atlassian Cloud", "https://id.atlassian.com", "https://confluence.atlassian.com/cloud/secure-your-account-with-two-step-verification-939505063.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Batch", "https://batch.com", "https://help.batch.com/en/articles/2721053");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitbucket", "https://bitbucket.org", "https://confluence.atlassian.com/x/425QLg");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buddy", "https://buddy.works", "https://buddy.works/blog/introducing-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bugsnag", "https://bugsnag.com", "https://docs.bugsnag.com/product/account-and-security/#security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bugzilla@Mozilla", "https://bugzilla.mozilla.org", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buildkite", "https://buildkite.com", "https://buildkite.com/changelog/31-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BuiltWith", "https://builtwith.com", "https://kb.builtwith.com/account-management/how-to-enable-2fa-on-builtwith/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Codeship", "https://codeship.com/", "https://documentation.codeship.com/general/about/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Compose", "https://www.compose.com/", "https://help.compose.com/docs/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Crowdin", "https://crowdin.com/", "https://support.crowdin.com/account-settings/#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DeployHQ", "https://www.deployhq.com/", "https://www.deployhq.com/support/managing-your-account/personal-profile/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Docker", "https://www.docker.com/", "https://www.docker.com/blog/designing-docker-hub-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Domino Data Lab", "https://www.dominodatalab.com/", "https://support.dominodatalab.com/hc/en-us/articles/115000998406");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Drupal.org", "https://www.drupal.org/", "https://www.drupal.org/drupalorg/docs/user-accounts/setting-up-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("elmah.io", "https://elmah.io", "https://docs.elmah.io/how-to-enable-two-factor-login/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Esri", "https://www.esri.com", "https://doc.arcgis.com/en/arcgis-online/reference/multifactor.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FogBugz & Kiln", "https://www.fogbugz.com/", "https://support.fogbugz.com/hc/en-us/articles/360011262434");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GitHub", "https://github.com", "https://help.github.com/en/github/authenticating-to-github/configuring-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("GitLab", "https://gitlab.com", "https://docs.gitlab.com/ee/user/profile/account/two_factor_authentication.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HashiCorp Terraform Enterprise", "https://app.terraform.io/", "https://www.terraform.io/docs/enterprise/users-teams-organizations/2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HashiCorp Vagrant Cloud", "https://app.vagrantup.com/", "https://www.vagrantup.com/docs/vagrant-cloud/users/authentication.html#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Heap Analytics", "https://heapanalytics.com/", "https://docs.heap.io/docs/2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("InVision", "https://www.invisionapp.com", "https://support.invisionapp.com/hc/en-us/articles/360033708112");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IT Glue", "https://www.itglue.com/", "https://support.itglue.com/hc/en-us/articles/360004933757");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("JetBrains", "https://jetbrains.com", "https://www.jetbrains.com/help/hub/2fa-with-token.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Koding", "https://koding.com", "https://www.koding.com/blog/2015/06/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Launchpad", "https://launchpad.net", "https://help.ubuntu.com/community/SSO/FAQs/2FA");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Looker", "https://looker.com/", "https://www.looker.com/docs/admin/security/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mapbox", "https://www.mapbox.com", "https://docs.mapbox.com/accounts/overview/settings/#security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Metrological", "https://www.metrological.com/", "https://github.com/2factorauth/twofactorauth/pull/2273#issuecomment-271876292");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MongoDB Cloud Manager", "https://cloud.mongodb.com", "https://docs.cloudmanager.mongodb.com/core/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("npm", "https://www.npmjs.com/", "https://docs.npmjs.com/configuring-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("NuGet", "https://www.nuget.org", "https://azure.microsoft.com/en-us/documentation/articles/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Packagist", "https://packagist.org", "https://github.com/composer/packagist/pull/1031");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Panic Sync", "https://panic.com/", "https://library.panic.com/general/sync-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Phacility", "https://phacility.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pivotal Tracker", "https://www.pivotaltracker.com", "https://www.pivotaltracker.com/help/articles/two_factor_auth/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ProfitWell", "https://profitwell.com", "https://learn.profitwell.com/article/wsudrpi199-setting-up-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Pushover", "https://pushover.net/", "https://support.pushover.app/i49");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PyPI", "https://pypi.org/", "https://pypi.org/help/#twofa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PythonAnywhere", "https://www.pythonanywhere.com", "https://help.pythonanywhere.com/pages/SecuringYourAccount/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Raygun", "https://raygun.com", "https://raygun.com/docs/workflow/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RBCommons", "https://rbcommons.com", "https://beanbag.freshdesk.com/support/solutions/articles/3000006998");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ReadMe", "https://readme.com", "https://docs.readme.com/docs/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Report URI", "https://report-uri.com", "https://scotthelme.co.uk/dealing-with-account-recovery-and-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rollbar", "https://rollbar.com/", "https://rollbar.com/docs/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("RubyGems.org", "https://rubygems.org", "https://guides.rubygems.org/setting-up-multifactor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Scripting Helpers", "https://scriptinghelpers.org/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Semaphore", "https://semaphoreci.com", "https://semaphoreci.com/docs/two-step-verification.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sentry", "https://sentry.io", "https://blog.sentry.io/2016/06/22/introducing-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SourceForge", "https://sourceforge.net/", "https://sourceforge.net/blog/introducing-multifactor-authentication-on-sourceforge/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("StatusCake", "https://statuscake.com/", "https://www.statuscake.com/kb/knowledge-base/how-to-change-the-statuscake-password-for-login/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sumo Logic", "https://www.sumologic.com", "https://help.sumologic.com/Manage/Security/About_2-Step_Verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Twilio", "https://www.twilio.com/", "https://support.twilio.com/hc/en-us/sections/360008377353");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Unbounce", "https://unbounce.com", "https://documentation.unbounce.com/hc/en-us/articles/360001372503");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Unity", "https://unity3d.com/", "https://support.unity3d.com/hc/en-us/articles/208764976");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Uptime Robot", "https://uptimerobot.com", "https://blog.uptimerobot.com/introducing-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Visual Studio Codespaces", "https://www.visualstudio.com/", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zapier", "https://zapier.com", "https://zapier.com/help/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("AnycoinDirect", "https://anycoindirect.eu", "https://support.anycoindirect.eu/hc/en-gb/articles/115001423191");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bcnex", "https://www.bcnex.net/", "https://support.bcnex.net/hc/en-us/articles/360019419173");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Binance", "https://www.binance.com/", "https://www.binance.com/en/support/faq/c-1#/1/11");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitBay", "https://bitbay.net/", "https://bitbay.net/en/safety");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitcoin.de", "https://bitcoin.de", "https://www.bitcoin.de/de/faq/was-ist-die-2-step-verification-2-faktor-authentifizierung/46.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitcoinTrade", "https://bitcointrade.com.br/", "https://blog.bitcointrade.com.br/2fa-o-que-e-e-como-cadastrar/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitfinex", "https://www.bitfinex.com", "https://support.bitfinex.com/hc/en-us/sections/203192029");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitflyer", "https://bitflyer.com", "https://bitflyer.com/en-jp/faq/2-10");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitGo", "https://www.bitgo.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bithumb", "https://www.bithumb.com/", "https://en.bithumb.com/customer_support/info_guide?seq=510");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BitMEX", "https://www.bitmex.com", "https://blog.bitmex.com/use-two-factor-authentication-and-dont-reuse-passwords/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitpanda", "https://www.bitpanda.com/", "https://support.bitpanda.com/hc/en-us/articles/360002015220");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitpay", "https://bitpay.com", "https://support.bitpay.com/hc/en-us/articles/360006612692");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitstamp", "https://bitstamp.net", "https://www.bitstamp.net/s/documents/bitstamp_2_factor_authentication_guide.pdf");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bittrex", "https://bittrex.com", "https://bittrex.zendesk.com/hc/en-us/articles/115000198612");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Blockchain", "https://blockchain.info/", "https://support.blockchain.com/hc/en-us/articles/211164103");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BlockFi", "https://blockfi.com/", "https://blockfi.com/blockfi-news/two-factor-authentication-2fa-now-available-for-all-blockfi-accounts/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Braziliex", "https://braziliex.com/", "https://braziliex.com/faq/index.php?id=288");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BTC BOX", "https://www.btcbox.co.jp/", "https://support.btcbox.co.jp/hc/en-us/articles/360001886053");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BTC Markets", "https://www.btcmarkets.net/", "https://www.btcmarkets.net/faq#q27");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("BTCPOP", "https://btcpop.co/", "https://blog.btcpop.co/2017/04/27/signing-security-btcpop-co-account/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Buda", "https://www.buda.com", "https://soporte.buda.com/es/articles/2379080");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bybit", "https://www.bybit.com/", "https://help.bybit.com/hc/en-us/articles/360039748653");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CEX.IO", "https://cex.io/", "https://cex.io/guide#4");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Changelly", "https://changelly.com/", "https://changelly.com/faq#what-is-2fa-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Circle", "https://circle.com", "https://support.circle.com/hc/en-us/articles/213560483");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coin Cafe", "https://coincafe.com", "https://coincafeinc.wordpress.com/2016/01/08/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinapult", "https://coinapult.com", "https://coinapult.com/faq");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinbase", "https://www.coinbase.com/", "https://support.coinbase.com/customer/en/portal/articles/1658338");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coincheck", "https://coincheck.com/", "https://faq.coincheck.com/s/article/20204?language=en_US");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinDeal", "https://coindeal.com", "https://coindeal.com/security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinFalcon", "https://coinfalcon.com/", "https://support.coinfalcon.com/en-us/article/-nkjppd/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinGate", "https://coingate.com", "https://support.coingate.com/en/65/-");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinify", "https://coinify.com/", "https://help.coinify.com/hc/en-us/articles/360014173320");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinjar", "https://coinjar.com", "https://support.coinjar.com/hc/en-us/articles/202910075");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinOne", "https://coinone.co.kr/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coins.ph", "https://coins.ph/", "https://support.coins.ph/hc/en-us/articles/202604924");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinspot", "https://www.coinspot.com.au/", "https://coinspot.zendesk.com/hc/en-us/sections/115000049254");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinTracker", "https://www.cointracker.io", "https://help.cointracker.io/en/articles/2641553");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("CoinTracking", "https://cointracking.info/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Coinut", "https://coinut.com/", "https://help.coinut.com/hc/en-us/articles/360005061354");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Crypto", "https://www.crypto.com", "https://help.crypto.com/en/articles/3511439");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cryptonator", "https://www.cryptonator.com", "https://cryptonator.zendesk.com/hc/en-us/articles/201715352");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DSX", "https://dsx.uk/", "https://docs.dsx.uk/dsx/getting-started-with-dsx/your-security-is-our-priority/enable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Gatehub", "https://gatehub.net", "https://support.gatehub.net/hc/en-us/articles/360021168234");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HitBTC", "https://www.hitbtc.com/", "https://support.hitbtc.com/en/support/solutions/articles/63000224976");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Invictus Capital", "https://invictuscapital.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Korbit", "https://www.korbit.co.kr", "https://support.korbit.co.kr/customer/en/portal/articles/1717692");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kraken", "https://www.kraken.com/", "https://support.kraken.com/hc/en-us/articles/360000426923");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Kuna", "https://www.kuna.io/", "https://support.kuna.io/en/support/solutions/articles/17000083405");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Liquid", "https://www.liquid.com/", "https://help.liquid.com/en/articles/2273273");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LiteBit", "https://www.litebit.eu/", "https://support.litebit.eu/hc/en-us/articles/115000953504");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LocalBitcoins", "https://localbitcoins.com/", "https://localbitcoins.com/guides/security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("LocalCryptos", "https://localcryptos.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Luno", "https://www.luno.com/", "https://www.luno.com/help/en/articles/1000203420");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MaiCoin", "https://www.maicoin.com", "https://maicoin2.freshdesk.com/en/support/solutions/articles/32000016116");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mercado Bitcoin", "https://www.mercadobitcoin.com.br/", "https://suporte.mercadobitcoin.com.br/hc/pt-br/articles/360000385152");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OKEx", "https://www.okex.com/", "https://www.okex.com/support/hc/en-us/articles/360000350271");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PayKassa", "https://paykassa.pro/", "https://paykassa.pro/en/news/s-paykassa-vashi-dannye-pod-nadejnoy-zashchitoy/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Poloniex", "https://poloniex.com/", "https://support.poloniex.circle.com/hc/en-us/articles/360025399352");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Remitano", "https://remitano.com/", "https://support.remitano.com/en/articles/781044");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SatoshiTango", "https://satoshitango.com/", "https://github.com/2factorauth/twofactorauth/pull/2321#issuecomment-273971890");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("STEX", "https://stex.com", "https://help.stex.com/en/articles/3486981#individual-account-security-settings");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Uphold", "https://uphold.com/", "https://support.uphold.com/hc/en-us/articles/360024042471");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("ViaBTC", "https://viabtc.com/", "https://support.viabtc.com/hc/en-us/articles/900001693343");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wirex", "https://wirexapp.com/", "https://wirexapp.com/hc/articles/207160259");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Action Network", "https://actionnetwork.org/", "https://help.actionnetwork.org/hc/en-us/articles/217206826");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Airship", "https://www.airship.com/", "https://docs.airship.com/tutorials/security/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Basecamp", "https://basecamp.com/", "https://3.basecamp-help.com/article/443--");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitrix24", "https://www.bitrix24.com/", "https://helpdesk.bitrix24.com/open/9800171/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Campfire", "https://campfirenow.com/", "https://help.37signals.com/sign-in/questions/480");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Capsule", "https://capsulecrm.com/", "https://capsulecrm.com/support/user-preferences/#enabling-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Close", "https://close.com/", "https://help.close.com/docs/enabling-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloze", "https://www.cloze.com/", "https://help.cloze.com/knowledge_base/topics/how-do-i-enable-2-step-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Customer.io", "https://customer.io", "https://customer.io/docs/two-factor-auth");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Direct Mail", "https://directmailmac.com", "https://directmailmac.com/support/article/507");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Discord", "https://discordapp.com/", "https://support.discordapp.com/hc/en-us/articles/219576828");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("FAX.PLUS", "https://www.fax.plus", "https://www.fax.plus/help/articles/how-can-i-enable-disable-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Front App", "https://frontapp.com", "https://help.frontapp.com/t/36249g");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Grape", "https://chatgrape.com/", "https://chatgrape.com/doc/deployment/2fa.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Groups.io", "https://groups.io", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hangouts", "https://hangouts.google.com/", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("HubSpot", "https://www.hubspot.com/", "https://knowledge.hubspot.com/articles/kcs_article/account/how-can-i-set-up-two-factor-authentication-for-my-hubspot-login");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Intercom", "https://www.intercom.com/", "https://www.intercom.com/help/en/articles/181");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MailChimp", "https://mailchimp.com/", "https://kb.mailchimp.com/accounts/login/set-up-a-two-factor-authentication-app-at-login");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mailgun", "https://www.mailgun.com", "https://help.mailgun.com/hc/en-us/articles/360011664433");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Missive App", "https://missiveapp.com/", "https://missiveapp.com/faq/enable-2-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nulab", "https://nulab.com/", "https://support.nulab.com/hc/en-us/articles/115001025087");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Postmarkapp", "https://www.postmarkapp.com/", "https://postmarkapp.com/support/article/1081-how-do-i-use-two-factor-authentication-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Salesforce", "https://www.salesforce.com", "https://developer.salesforce.com/docs/atlas.en-us.securityImplGuide.meta/securityImplGuide/add_time-based_token.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Skype", "https://www.skype.com", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Slack", "https://slack.com/", "https://get.slack.help/hc/en-us/articles/204509068");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SocketLabs", "https://socketlabs.com/", "https://help.socketlabs.com/docs/two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("SparkPost", "https://sparkpost.com/", "https://www.sparkpost.com/docs/my-account-and-profile/enabling-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Stackfield", "https://www.stackfield.com/", "https://www.stackfield.com/help/-2032");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zoom", "https://www.zoom.us", "https://support.zoom.us/hc/en-us/articles/360038247071");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Amazon Web Services", "https://aws.amazon.com", "https://aws.amazon.com/iam/features/mfa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Brightbox", "https://www.brightbox.com/", "https://www.brightbox.com/docs/guides/manager/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloud 66", "https://www.cloud66.com", "https://blog.cloud66.com/two-factor-authentication-for-your-accounts/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("cloud.ca", "https://cloud.ca", "https://cloud.ca/two-factor-authentication-is-now-available-on-cloud-ca/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("DigitalOcean", "https://www.digitalocean.com/", "https://www.digitalocean.com/docs/accounts/security/2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Engine Yard", "https://www.engineyard.com", "https://support.cloud.engineyard.com/hc/en-us/community/posts/203752678");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Equinix Metal", "https://metal.equinix.com", "https://metal.equinix.com/developers/docs/accounts/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("fortrabbit", "https://www.fortrabbit.com/", "https://help.fortrabbit.com/account#toc-setting-up-2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Cloud Platform", "https://cloud.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Heroku", "https://www.heroku.com/", "https://devcenter.heroku.com/articles/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Hostiso", "https://hostiso.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("IBM Cloud", "https://cloud.ibm.com", "https://cloud.ibm.com/docs/iam?topic=iam-types");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Jelastic", "https://jelastic.com", "https://docs.jelastic.com/two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Joyent", "https://www.joyent.com/", "https://docs.joyent.com/public-cloud/getting-started/2fa");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Laravel Forge", "https://forge.laravel.com/", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Leaseweb", "https://www.leaseweb.com/", "https://kb.leaseweb.com/users-and-accounts/managing-your-profile/setup-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Linode", "https://www.linode.com/", "https://www.linode.com/docs/security/linode-manager-security-controls");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("MacStadium", "https://www.macstadium.com/", "https://help.macstadium.com/articles/macstadium-two-factor-authentication-guide");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Microsoft Azure", "https://azure.microsoft.com/", "https://azure.microsoft.com/en-us/documentation/articles/multi-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("mLab", "https://mlab.com/", "https://docs.mlab.com/security/#two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Rackspace", "https://www.rackspace.com/", "https://support.rackspace.com/how-to/multi-factor-authentication-from-the-cloud-control-panel/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Scaleway", "https://www.scaleway.com", "https://blog.scaleway.com/2017/introducing-two-factor-authentication-on-scaleway/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Scalr", "https://www.scalr.com", "https://scalr-wiki.atlassian.net/wiki/display/docs/Two-Factor+Authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tilaa", "https://www.tilaa.com", "https://support.tilaa.com/hc/en-us/articles/360020167352");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("UpCloud", "https://www.upcloud.com", "https://www.upcloud.com/support/two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Userify", "https://userify.com", "https://userify.com/docs/multifactor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Vultr", "https://www.vultr.com", "https://www.vultr.com/docs/using-two-factor-authentication-to-login-to-vultr-control-panel");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Betfair", "https://www.betfair.com/", "https://support.betfair.com/app/answers/detail/a_id/126");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Betvictor", "https://www.betvictor.com", "");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Cloudbet", "https://www.cloudbet.com/", "https://cloudbet.zendesk.com/hc/en-us/articles/223120088/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Smarkets", "https://www.smarkets.com/", "https://help.smarkets.com/hc/en-gb/articles/115000822171");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Addiko Bank", "https://www.addiko.hr/", "https://www.addiko.hr/static/uploads/mtoken-uputa-za-koristenje.pdf");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Avanza", "https://www.avanza.se/", "https://www.avanza.se/kundservice.html/1335/tvafaktorsinloggning/d264248e-bea3-48a0-bf2d-157309734649");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Bitwala", "https://www.bitwala.com/", "https://support.bitwala.com/hc/en-gb/articles/360000613360");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Woodforest National Bank", "https://www.woodforest.com/", "https://www.woodforest.com/Personal/Services/Online-Banking/Online-Banking-Security");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Backblaze", "https://www.backblaze.com", "https://help.backblaze.com/hc/en-us/articles/217666588");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Dropbox", "https://www.dropbox.com", "https://help.dropbox.com/security/enable-two-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Evernote", "https://evernote.com", "https://help.evernote.com/hc/en-us/articles/208314238");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Files.com", "https://www.files.com", "https://www.files.com/docs/features/two-factor-auth/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Google Drive", "https://drive.google.com", "https://www.google.com/intl/en-US/landing/2step/features.html");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Jottacloud", "https://www.jottacloud.com", "https://docs.jottacloud.com/en/articles/1292931");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Koofr", "https://koofr.eu", "https://koofr.eu/help/other/how-do-i-enable-2-step-verification/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Mega", "https://mega.nz/", "https://mega.nz/help/client/webclient/security-and-privacy/5bb5436cf1b70966038b456b");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Nimbox", "https://www.nimbox.co.uk/", "https://www.nimbox.co.uk/help-centre/two-step-two-factor-authentication-2fa/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("OneDrive", "https://onedrive.live.com", "https://support.microsoft.com/en-us/help/12408/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("PCloud", "https://www.pcloud.com", "https://www.pcloud.com/help/general-help-center/how-can-i-set-up-two-factor-authentication");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("QNAP", "https://www.qnap.com", "https://www.qnap.com/en-us/how-to/tutorial/article/how-to-enhance-account-security-using-2-step-verification");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Sync", "https://www.sync.com", "https://www.sync.com/help/how-do-i-setup-two-factor-authentication/");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Synology", "https://www.synology.com/", "https://originwww.synology.com/en-us/knowledgebase/tutorials/615#t5");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Tresorit", "https://tresorit.com/", "https://support.tresorit.com/hc/en-us/articles/216114527");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Wasabi", "https://wasabi.com/", "https://wasabi.com/wp-content/themes/wasabi/docs/User_Guide/index.html#t=topics%2FCONSOLE_ACCESS_for_the_Root_User.htm");
INSERT INTO "providers" ("name", "website", "help_url") VALUES ("Zoolz", "https://intelli.zoolz.com/", "https://wiki.zoolz.com/how-do-i-enable-two-factor-authentication-on-my-zoolz-intelligent-account/");
INSERT INTO "providers" ("name", "website", "help_url", "digits") VALUES ("Battle.net", "https://battle.net", "https://eu.battle.net/support/en/article/10363", 8);
INSERT INTO "providers" ("name", "website", "help_url", "digits") VALUES ("Blizzard", "https://blizzard.com", "https://eu.battle.net/support/en/article/10363", 8);
INSERT INTO "providers" ("name", "website") VALUES ("Gitea", "https://gitea.io");
