DELETE FROM "providers" WHERE "name"="Zonda";
UPDATE "providers" SET name="Zoho Mail" WHERE name="Zoho";
DELETE FROM "providers" WHERE "name"="Zerodha Kite";
DELETE FROM "providers" WHERE "name"="YouHodler";
DELETE FROM "providers" WHERE "name"="Xplenty";
DELETE FROM "providers" WHERE "name"="Xink";
DELETE FROM "providers" WHERE "name"="Wyze";
DELETE FROM "providers" WHERE "name"="Wrike";
DELETE FROM "providers" WHERE "name"="Workplace";
DELETE FROM "providers" WHERE "name"="Workflowy";
DELETE FROM "providers" WHERE "name"="Workato";
DELETE FROM "providers" WHERE "name"="Wordfence Central";
DELETE FROM "providers" WHERE "name"="WoltLab";
DELETE FROM "providers" WHERE "name"="Wolf.bet";
DELETE FROM "providers" WHERE "name"="Wiggle";
DELETE FROM "providers" WHERE "name"="Whois";
DELETE FROM "providers" WHERE "name"="Whimsical";
DELETE FROM "providers" WHERE "name"="When I Work";
DELETE FROM "providers" WHERE "name"="Web Hosting Canada";
DELETE FROM "providers" WHERE "name"="WhaleFin";
DELETE FROM "providers" WHERE "name"="WEDOS";
UPDATE "providers" SET help_url="https://docs.webroot.com/us/en/home/wsa_website_userguide/wsa_managementwebsite_userguide.htm#GettingStarted/Enabling2-FactorAuthentication.htm" WHERE name="Webroot";
DELETE FROM "providers" WHERE "name"="POST Luxembourg";
DELETE FROM "providers" WHERE "name"="Webcentral";
DELETE FROM "providers" WHERE "name"="500px";
DELETE FROM "providers" WHERE "name"="Wealthify";
DELETE FROM "providers" WHERE "name"="WazirX";
DELETE FROM "providers" WHERE "name"="Warner Bros. Games";
DELETE FROM "providers" WHERE "name"="Vysoká škola ekonomická v Praze";
DELETE FROM "providers" WHERE "name"="VoIP.ms";
DELETE FROM "providers" WHERE "name"="VMware";
UPDATE "providers" SET website="https://www.visualstudio.com/" WHERE name="Visual Studio Codespaces";
DELETE FROM "providers" WHERE "name"="Vimeo";
DELETE FROM "providers" WHERE "name"="VicRoads";
DELETE FROM "providers" WHERE "name"="Verpex";
DELETE FROM "providers" WHERE "name"="Veracode";
DELETE FROM "providers" WHERE "name"="VeeroTech";
DELETE FROM "providers" WHERE "name"="Laravel Vapor";
DELETE FROM "providers" WHERE "name"="Vancity";
DELETE FROM "providers" WHERE "name"="Valr";
DELETE FROM "providers" WHERE "name"="Fathom Analytics";
DELETE FROM "providers" WHERE "name"="University of Pennsylvania";
DELETE FROM "providers" WHERE "name"="UpdraftPlus";
DELETE FROM "providers" WHERE "name"="Unstoppable Domains";
DELETE FROM "providers" WHERE "name"="Unleashed Inventory";
UPDATE "providers" SET website="https://unity3d.com/", help_url="https://support.unity3d.com/hc/en-us/articles/208764976" WHERE name="Unity";
UPDATE "providers" SET help_url="https://help.uniteddomains.com/hc/en-us/articles/115001458813", name="United Domains USA" WHERE name="ud.com";
DELETE FROM "providers" WHERE "name"="Unfuddle STACK";
UPDATE "providers" SET name="Ukraine" WHERE name="Hosting Ukraine";
UPDATE "providers" SET help_url="https://github.com/2factorauth/twofactorauth/pull/3845#issuecomment-491518360" WHERE name="UK2";
UPDATE "providers" SET help_url="https://help.ubnt.com/hc/en-us/articles/115012986607" WHERE name="Ubiquiti Inc";
DELETE FROM "providers" WHERE "name"="University of Calgary";
DELETE FROM "providers" WHERE "name"="Union Bank & Trust";
UPDATE "providers" SET website="https://uplay.ubi.com/", help_url="https://support.ubi.com/en-GB/Faqs/000039953" WHERE name="Ubisoft/Uplay";
DELETE FROM "providers" WHERE "name"="Uber Eats";
DELETE FROM "providers" WHERE "name"="Txbit";
UPDATE "providers" SET help_url="https://support.twitter.com/articles/20170388" WHERE name="Twitter";
DELETE FROM "providers" WHERE "name"="Tweakers";
DELETE FROM "providers" WHERE "name"="Technische Universität Berlin";
DELETE FROM "providers" WHERE "name"="T. Rowe Price";
DELETE FROM "providers" WHERE "name"="Trovo";
DELETE FROM "providers" WHERE "name"="Trimble";
UPDATE "providers" SET help_url="https://help.trello.com/article/993--" WHERE name="Trello";
DELETE FROM "providers" WHERE "name"="Travala";
DELETE FROM "providers" WHERE "name"="TradingView";
DELETE FROM "providers" WHERE "name"="Trading 212";
DELETE FROM "providers" WHERE "name"="Toshl";
DELETE FROM "providers" WHERE "name"="Toronto Metropolitan University";
DELETE FROM "providers" WHERE "name"="Todoist";
DELETE FROM "providers" WHERE "name"="Timetastic";
UPDATE "providers" SET website="https://www.time4vps.eu/", help_url="https://billing.time4vps.eu/knowledgebase/article/100/2-factor-authentication/" WHERE name="Time4VPS";
DELETE FROM "providers" WHERE "name"="Tito";
DELETE FROM "providers" WHERE "name"="ThriveCart";
DELETE FROM "providers" WHERE "name"="TherapyNotes";
DELETE FROM "providers" WHERE "name"="Textlocal";
DELETE FROM "providers" WHERE "name"="Termius";
DELETE FROM "providers" WHERE "name"="Telnyx";
DELETE FROM "providers" WHERE "name"="Technic";
DELETE FROM "providers" WHERE "name"="Teamwork";
UPDATE "providers" SET help_url="https://www.teamviewer.com/en/help/402-How-do-I-activate-deactivate-two-factor-authentication-for-my-TeamViewer-account.aspx" WHERE name="TeamViewer";
DELETE FROM "providers" WHERE "name"="TaxDome";
DELETE FROM "providers" WHERE "name"="TaxBit";
DELETE FROM "providers" WHERE "name"="Tauros";
DELETE FROM "providers" WHERE "name"="Talkdesk";
DELETE FROM "providers" WHERE "name"="Taboola";
DELETE FROM "providers" WHERE "name"="Tableau";
UPDATE "providers" SET help_url="https://support.t-mobile.com/docs/DOC-2727" WHERE name="T-Mobile";
DELETE FROM "providers" WHERE "name"="System76";
UPDATE "providers" SET help_url="https://originwww.synology.com/en-us/knowledgebase/tutorials/615#t5" WHERE name="Synology";
DELETE FROM "providers" WHERE "name"="Swyftx";
DELETE FROM "providers" WHERE "name"="Survicate";
DELETE FROM "providers" WHERE "name"="Substack";
DELETE FROM "providers" WHERE "name"="Studio Ninja";
DELETE FROM "providers" WHERE "name"="Federal Student Aid";
DELETE FROM "providers" WHERE "name"="STRATO";
DELETE FROM "providers" WHERE "name"="StormGain";
DELETE FROM "providers" WHERE "name"="Stessa";
DELETE FROM "providers" WHERE "name"="Statuspage";
DELETE FROM "providers" WHERE "name"="Standard Notes";
DELETE FROM "providers" WHERE "name"="MyFRITZ!";
DELETE FROM "providers" WHERE "name"="Square Enix";
DELETE FROM "providers" WHERE "name"="SproutSocial";
DELETE FROM "providers" WHERE "name"="Spring";
DELETE FROM "providers" WHERE "name"="Spreedly";
DELETE FROM "providers" WHERE "name"="Splashtop";
DELETE FROM "providers" WHERE "name"="SpectroCoin";
DELETE FROM "providers" WHERE "name"="SpaceHey";
DELETE FROM "providers" WHERE "name"="SouthXchange";
DELETE FROM "providers" WHERE "name"="Sonix";
DELETE FROM "providers" WHERE "name"="SolarWinds";
DELETE FROM "providers" WHERE "name"="Socialbakers";
DELETE FROM "providers" WHERE "name"="SmartSurvey";
DELETE FROM "providers" WHERE "name"="Smartly.io";
DELETE FROM "providers" WHERE "name"="Skinport";
DELETE FROM "providers" WHERE "name"="Sketch";
DELETE FROM "providers" WHERE "name"="Sisense Cloud Data Teams";
DELETE FROM "providers" WHERE "name"="sipgate";
DELETE FROM "providers" WHERE "name"="SimplyBook";
DELETE FROM "providers" WHERE "name"="SimpleLogin";
DELETE FROM "providers" WHERE "name"="SignRequest";
DELETE FROM "providers" WHERE "name"="Shrimpy";
DELETE FROM "providers" WHERE "name"="Shortcut";
DELETE FROM "providers" WHERE "name"="Shift4Shop";
DELETE FROM "providers" WHERE "name"="Shareworks";
DELETE FROM "providers" WHERE "name"="Simon Fraser University";
DELETE FROM "providers" WHERE "name"="San Francisco Fire Credit Union";
DELETE FROM "providers" WHERE "name"="Serverspace";
DELETE FROM "providers" WHERE "name"="ServerPilot";
DELETE FROM "providers" WHERE "name"="Server.pro";
DELETE FROM "providers" WHERE "name"="Wyre";
DELETE FROM "providers" WHERE "name"="SendSafely";
DELETE FROM "providers" WHERE "name"="SendOwl";
DELETE FROM "providers" WHERE "name"="Sendinblue";
DELETE FROM "providers" WHERE "name"="Sendcloud";
DELETE FROM "providers" WHERE "name"="State Employees Federal Credit Union";
DELETE FROM "providers" WHERE "name"="SecurityTrails";
DELETE FROM "providers" WHERE "name"="SeatGeek";
UPDATE "providers" SET help_url="https://blog.scaleway.com/2017/introducing-two-factor-authentication-on-scaleway/" WHERE name="Scaleway";
DELETE FROM "providers" WHERE "name"="ScaleGrid";
DELETE FROM "providers" WHERE "name"="Scalefusion";
DELETE FROM "providers" WHERE "name"="Sailthru";
DELETE FROM "providers" WHERE "name"="University of Groningen";
DELETE FROM "providers" WHERE "name"="Roblox";
DELETE FROM "providers" WHERE "name"="RMIT University";
DELETE FROM "providers" WHERE "name"="River Financial";
DELETE FROM "providers" WHERE "name"="Rippling";
DELETE FROM "providers" WHERE "name"="Ring";
DELETE FROM "providers" WHERE "name"="RightCapital";
DELETE FROM "providers" WHERE "name"="Rewind";
DELETE FROM "providers" WHERE "name"="RevenueCat";
DELETE FROM "providers" WHERE "name"="Rev";
DELETE FROM "providers" WHERE "name"="Republic";
DELETE FROM "providers" WHERE "name"="Replicon";
DELETE FROM "providers" WHERE "name"="Render";
DELETE FROM "providers" WHERE "name"="Rejoiner";
DELETE FROM "providers" WHERE "name"="Register365";
DELETE FROM "providers" WHERE "name"="Refersion";
DELETE FROM "providers" WHERE "name"="RedShelf";
DELETE FROM "providers" WHERE "name"="Redis Enterprise Cloud";
DELETE FROM "providers" WHERE "name"="Red Hat";
DELETE FROM "providers" WHERE "name"="Recruitee";
DELETE FROM "providers" WHERE "name"="Rebel.com";
DELETE FROM "providers" WHERE "name"="RapidAPI";
DELETE FROM "providers" WHERE "name"="Ramp";
DELETE FROM "providers" WHERE "name"="Quidax";
UPDATE "providers" SET help_url="https://accounts-help.lc.intuit.com/questions/1590157" WHERE name="Quickbooks Online";
DELETE FROM "providers" WHERE "name"="Questrade";
DELETE FROM "providers" WHERE "name"="Qantas";
DELETE FROM "providers" WHERE "name"="Putler";
UPDATE "providers" SET help_url="https://support.pushover.app/i49" WHERE name="Pushover";
DELETE FROM "providers" WHERE "name"="Pusher";
DELETE FROM "providers" WHERE "name"="Proton";
DELETE FROM "providers" WHERE "name"="Protolabs";
DELETE FROM "providers" WHERE "name"="Prostocash";
DELETE FROM "providers" WHERE "name"="ProBit";
DELETE FROM "providers" WHERE "name"="Practice Better";
DELETE FROM "providers" WHERE "name"="PowerReviews";
DELETE FROM "providers" WHERE "name"="Postman";
UPDATE "providers" SET help_url="https://support.poloniex.circle.com/hc/en-us/articles/360025399352" WHERE name="Poloniex";
DELETE FROM "providers" WHERE "name"="Poli Systems";
DELETE FROM "providers" WHERE "name"="POEditor";
DELETE FROM "providers" WHERE "name"="Podio";
DELETE FROM "providers" WHERE "name"="Russian Post (Почта России)";
UPDATE "providers" SET help_url="https://pobox.com/helpspot/index.php?pg=kb.chapter&id=65" WHERE name="Pobox";
DELETE FROM "providers" WHERE "name"="Black Desert";
DELETE FROM "providers" WHERE "name"="Plesk 360";
DELETE FROM "providers" WHERE "name"="Planning Center";
DELETE FROM "providers" WHERE "name"="Plaid";
DELETE FROM "providers" WHERE "name"="Pixieset";
DELETE FROM "providers" WHERE "name"="Piwik PRO";
DELETE FROM "providers" WHERE "name"="Phrase";
DELETE FROM "providers" WHERE "name"="Philips Hue";
DELETE FROM "providers" WHERE "name"="Phemex";
DELETE FROM "providers" WHERE "name"="Personal Capital";
DELETE FROM "providers" WHERE "name"="Perimeter 81";
DELETE FROM "providers" WHERE "name"="PC Case Gear";
DELETE FROM "providers" WHERE "name"="Payworks";
DELETE FROM "providers" WHERE "name"="Paycor";
DELETE FROM "providers" WHERE "name"="Paxos";
DELETE FROM "providers" WHERE "name"="Paxful";
DELETE FROM "providers" WHERE "name"="Passfolio";
DELETE FROM "providers" WHERE "name"="Particle";
UPDATE "providers" SET website="https://www.parsecgaming.com", help_url="https://support.parsecgaming.com/hc/en-us/articles/360015480691" WHERE name="Parsec";
DELETE FROM "providers" WHERE "name"="Paritex";
DELETE FROM "providers" WHERE "name"="Parimatch";
DELETE FROM "providers" WHERE "name"="Parallels";
DELETE FROM "providers" WHERE "name"="OzBargain";
DELETE FROM "providers" WHERE "name"="University of Oxford";
DELETE FROM "providers" WHERE "name"="Outbrain";
DELETE FROM "providers" WHERE "name"="University of Otago";
DELETE FROM "providers" WHERE "name"="The Ohio State University";
DELETE FROM "providers" WHERE "name"="Open Science Framework (OSF)";
DELETE FROM "providers" WHERE "name"="Optimizely";
UPDATE "providers" SET website="https://www.openprovider.co.uk" WHERE name="Openprovider";
DELETE FROM "providers" WHERE "name"="Open Collective";
DELETE FROM "providers" WHERE "name"="Malwarebytes OneView";
DELETE FROM "providers" WHERE "name"="Onet";
DELETE FROM "providers" WHERE "name"="OneSignal";
DELETE FROM "providers" WHERE "name"="Onehub";
DELETE FROM "providers" WHERE "name"="One.com";
DELETE FROM "providers" WHERE "name"="Labcorp OnDemand";
DELETE FROM "providers" WHERE "name"="OKX";
DELETE FROM "providers" WHERE "name"="Oculus";
DELETE FROM "providers" WHERE "name"="Nuri";
DELETE FROM "providers" WHERE "name"="Nozbe Teams";
DELETE FROM "providers" WHERE "name"="Notejoy";
DELETE FROM "providers" WHERE "name"="Norton";
DELETE FROM "providers" WHERE "name"="NordVPN";
DELETE FROM "providers" WHERE "name"="NordLocker";
DELETE FROM "providers" WHERE "name"="NordLayer";
DELETE FROM "providers" WHERE "name"="No-IP";
DELETE FROM "providers" WHERE "name"="Nimbus Note";
DELETE FROM "providers" WHERE "name"="Nifty";
DELETE FROM "providers" WHERE "name"="NiceHash";
DELETE FROM "providers" WHERE "name"="Niagahoster";
DELETE FROM "providers" WHERE "name"="NextDNS";
DELETE FROM "providers" WHERE "name"="Nexcess";
DELETE FROM "providers" WHERE "name"="Newgrounds";
DELETE FROM "providers" WHERE "name"="Maropost Commerce Cloud";
DELETE FROM "providers" WHERE "name"="Netim";
UPDATE "providers" SET name="Netcup" WHERE name="netcup";
DELETE FROM "providers" WHERE "name"="Netcore Cloud Email API";
DELETE FROM "providers" WHERE "name"="Nest";
DELETE FROM "providers" WHERE "name"="NDAX";
DELETE FROM "providers" WHERE "name"="University of Notre Dame";
DELETE FROM "providers" WHERE "name"="NameHero";
DELETE FROM "providers" WHERE "name"="Namebase";
DELETE FROM "providers" WHERE "name"="NairaEx";
DELETE FROM "providers" WHERE "name"="NAGA";
DELETE FROM "providers" WHERE "name"="N-able";
DELETE FROM "providers" WHERE "name"="Pennsylvania Dept of Revenue myPATH";
DELETE FROM "providers" WHERE "name"="MYOB";
DELETE FROM "providers" WHERE "name"="Emma Email Marketing";
DELETE FROM "providers" WHERE "name"="MyAnimeList";
DELETE FROM "providers" WHERE "name"="MxToolbox";
DELETE FROM "providers" WHERE "name"="MURAL";
DELETE FROM "providers" WHERE "name"="Masaryk University";
DELETE FROM "providers" WHERE "name"="Mos.ru";
DELETE FROM "providers" WHERE "name"="Morgan Stanley";
DELETE FROM "providers" WHERE "name"="Moqups";
DELETE FROM "providers" WHERE "name"="MongoDB";
DELETE FROM "providers" WHERE "name"="Monex";
DELETE FROM "providers" WHERE "name"="Monday.com";
DELETE FROM "providers" WHERE "name"="Mist";
DELETE FROM "providers" WHERE "name"="Miro";
UPDATE "providers" SET website="https://www.mint.com", help_url="https://help.mint.com/Security/908045661" WHERE name="Mint";
DELETE FROM "providers" WHERE "name"="Mineplex";
DELETE FROM "providers" WHERE "name"="Minecraft";
DELETE FROM "providers" WHERE "name"="Meta";
DELETE FROM "providers" WHERE "name"="Mercury";
DELETE FROM "providers" WHERE "name"="Mercury Cash";
DELETE FROM "providers" WHERE "name"="Mercado Libre";
DELETE FROM "providers" WHERE "name"="Memsource";
UPDATE "providers" SET website="https://mega.nz/", help_url="https://mega.nz/help/client/webclient/security-and-privacy/5bb5436cf1b70966038b456b" WHERE name="Mega";
DELETE FROM "providers" WHERE "name"="Google Meet";
DELETE FROM "providers" WHERE "name"="Mattermost";
DELETE FROM "providers" WHERE "name"="Matomo Cloud";
DELETE FROM "providers" WHERE "name"="Make";
DELETE FROM "providers" WHERE "name"="Mailo";
DELETE FROM "providers" WHERE "name"="Yahoo Mail";
DELETE FROM "providers" WHERE "name"="SAPO Mail";
DELETE FROM "providers" WHERE "name"="Mail.com";
DELETE FROM "providers" WHERE "name"="Mountain America Credit Union";
UPDATE "providers" SET help_url="https://help.macstadium.com/articles/macstadium-two-factor-authentication-guide" WHERE name="MacStadium";
DELETE FROM "providers" WHERE "name"="M1 Finance";
DELETE FROM "providers" WHERE "name"="Lokalise";
UPDATE "providers" SET help_url="https://support.logmeininc.com/pro/help#logmein-t-login-policy-set-twofactor-ownaccount" WHERE name="LogMeIn";
DELETE FROM "providers" WHERE "name"="Logitech";
DELETE FROM "providers" WHERE "name"="LocalMonero";
DELETE FROM "providers" WHERE "name"="Localize";
DELETE FROM "providers" WHERE "name"="LIHKG";
DELETE FROM "providers" WHERE "name"="LCN.com";
DELETE FROM "providers" WHERE "name"="LaunchDarkly";
DELETE FROM "providers" WHERE "name"="LATOKEN";
DELETE FROM "providers" WHERE "name"="Larian";
DELETE FROM "providers" WHERE "name"="Krystal";
DELETE FROM "providers" WHERE "name"="Kriptomat";
DELETE FROM "providers" WHERE "name"="Knack";
DELETE FROM "providers" WHERE "name"="Klaviyo";
DELETE FROM "providers" WHERE "name"="Kintone";
DELETE FROM "providers" WHERE "name"="Kinsta";
DELETE FROM "providers" WHERE "name"="KickEX";
DELETE FROM "providers" WHERE "name"="justhost";
DELETE FROM "providers" WHERE "name"="JumpCloud";
DELETE FROM "providers" WHERE "name"="Jovia Financial";
DELETE FROM "providers" WHERE "name"="Mastodon";
DELETE FROM "providers" WHERE "name"="Nutstore";
UPDATE "providers" SET help_url="https://www.jetbrains.com/help/hub/2fa-with-token.html" WHERE name="JetBrains";
DELETE FROM "providers" WHERE "name"="Jamf Now";
DELETE FROM "providers" WHERE "name"="Iterable";
UPDATE "providers" SET name="1&1 IONOS" WHERE name="IONOS";
DELETE FROM "providers" WHERE "name"="Voyager";
DELETE FROM "providers" WHERE "name"="Intuit";
DELETE FROM "providers" WHERE "name"="InterServer";
UPDATE "providers" SET website="https://www.internet.bs", help_url="/notes/internetbs/" WHERE name="Internet.bs";
DELETE FROM "providers" WHERE "name"="InMotion Hosting";
UPDATE "providers" SET help_url="https://www.infomaniak.ch/en/support/faq/1940" WHERE name="Infomaniak";
DELETE FROM "providers" WHERE "name"="Independer";
DELETE FROM "providers" WHERE "name"="Independent Reserve";
DELETE FROM "providers" WHERE "name"="ImprovMX";
UPDATE "providers" SET help_url="https://www.youtube.com/watch?v=37Tgxy3NoG4" WHERE name="ImmobilienScout24";
DELETE FROM "providers" WHERE "name"="IDrive";
UPDATE "providers" SET help_url="https://confluence.atlassian.com/cloud/secure-your-account-with-two-step-verification-939505063.html" WHERE name="Atlassian Cloud";
DELETE FROM "providers" WHERE "name"="Hypixel";
DELETE FROM "providers" WHERE "name"="Huobi";
DELETE FROM "providers" WHERE "name"="Huawei Cloud";
DELETE FROM "providers" WHERE "name"="HP";
DELETE FROM "providers" WHERE "name"="Hotjar";
DELETE FROM "providers" WHERE "name"="Hostwinds";
DELETE FROM "providers" WHERE "name"="HostMonster";
DELETE FROM "providers" WHERE "name"="Hostinger";
DELETE FROM "providers" WHERE "name"="Hostek";
DELETE FROM "providers" WHERE "name"="Honeybadger";
DELETE FROM "providers" WHERE "name"="Sophos Home";
DELETE FROM "providers" WHERE "name"="Saxo Bank";
DELETE FROM "providers" WHERE "name"="Home Assistant";
DELETE FROM "providers" WHERE "name"="HMRC";
DELETE FROM "providers" WHERE "name"="HiDrive (STRATO)";
DELETE FROM "providers" WHERE "name"="hide.me VPN";
DELETE FROM "providers" WHERE "name"="Hevo Data";
DELETE FROM "providers" WHERE "name"="Hetzner";
DELETE FROM "providers" WHERE "name"="Stake";
DELETE FROM "providers" WHERE "name"="VRChat";
DELETE FROM "providers" WHERE "name"="Heap";
DELETE FROM "providers" WHERE "name"="Hatch";
DELETE FROM "providers" WHERE "name"="HappyFox";
DELETE FROM "providers" WHERE "name"="Hack The Box";
DELETE FROM "providers" WHERE "name"="Guilded";
DELETE FROM "providers" WHERE "name"="Guideline";
DELETE FROM "providers" WHERE "name"="GreenGeeks";
DELETE FROM "providers" WHERE "name"="Teleport";
DELETE FROM "providers" WHERE "name"="Госуслуги (Gosuslugi)";
DELETE FROM "providers" WHERE "name"="GoSquared";
DELETE FROM "providers" WHERE "name"="Abode";
DELETE FROM "providers" WHERE "name"="GMX.com";
DELETE FROM "providers" WHERE "name"="Glassdoor";
UPDATE "providers" SET help_url="https://help.github.com/en/github/authenticating-to-github/configuring-two-factor-authentication" WHERE name="GitHub";
DELETE FROM "providers" WHERE "name"="Getscreen.me";
DELETE FROM "providers" WHERE "name"="Pocket";
DELETE FROM "providers" WHERE "name"="GeForce (Nvidia)";
DELETE FROM "providers" WHERE "name"="Gate.io";
DELETE FROM "providers" WHERE "name"="GameMaker";
DELETE FROM "providers" WHERE "name"="Galaxus";
DELETE FROM "providers" WHERE "name"="FTX";
DELETE FROM "providers" WHERE "name"="Frontify";
DELETE FROM "providers" WHERE "name"="Freshworks";
DELETE FROM "providers" WHERE "name"="Freewallet";
DELETE FROM "providers" WHERE "name"="Freehostia";
DELETE FROM "providers" WHERE "name"="Frame";
DELETE FROM "providers" WHERE "name"="FragDenStaat";
DELETE FROM "providers" WHERE "name"="Formspree";
DELETE FROM "providers" WHERE "name"="Formsite";
UPDATE "providers" SET name="FogBugz & Kiln" WHERE name="FogBugz";
DELETE FROM "providers" WHERE "name"="Flourish";
DELETE FROM "providers" WHERE "name"="Firmex VDR";
DELETE FROM "providers" WHERE "name"="Finnair";
DELETE FROM "providers" WHERE "name"="Finary";
DELETE FROM "providers" WHERE "name"="Filen";
DELETE FROM "providers" WHERE "name"="Favro";
DELETE FROM "providers" WHERE "name"="Fauna";
DELETE FROM "providers" WHERE "name"="FaucetPay";
DELETE FROM "providers" WHERE "name"="Faucet Crypto";
DELETE FROM "providers" WHERE "name"="Fathom";
UPDATE "providers" SET name="FastMail" WHERE name="Fastmail";
DELETE FROM "providers" WHERE "name"="FastComet";
DELETE FROM "providers" WHERE "name"="FanDuel";
DELETE FROM "providers" WHERE "name"="Falcon";
DELETE FROM "providers" WHERE "name"="Exmo";
DELETE FROM "providers" WHERE "name"="eUKhost";
DELETE FROM "providers" WHERE "name"="Etana Custody";
DELETE FROM "providers" WHERE "name"="ESET HOME";
DELETE FROM "providers" WHERE "name"="Epik";
DELETE FROM "providers" WHERE "name"="E.ON";
DELETE FROM "providers" WHERE "name"="Envoyer";
UPDATE "providers" SET help_url="https://www.enom.com/kb/kb/kb_1687-setup-2-factor.htm" WHERE name="eNom";
DELETE FROM "providers" WHERE "name"="Eneba";
DELETE FROM "providers" WHERE "name"="EmailMeForm";
DELETE FROM "providers" WHERE "name"="Elastic Cloud";
DELETE FROM "providers" WHERE "name"="Egnyte";
DELETE FROM "providers" WHERE "name"="eclincher";
DELETE FROM "providers" WHERE "name"="EasySendy";
DELETE FROM "providers" WHERE "name"="Earth Class Mail";
DELETE FROM "providers" WHERE "name"="Drift";
DELETE FROM "providers" WHERE "name"="Doppler";
UPDATE "providers" SET help_url="https://www.docker.com/blog/designing-docker-hub-2fa/" WHERE name="Docker";
DELETE FROM "providers" WHERE "name"="DNSFilter";
DELETE FROM "providers" WHERE "name"="DMOJ";
DELETE FROM "providers" WHERE "name"="DMM";
UPDATE "providers" SET website="https://discordapp.com/", help_url="https://support.discordapp.com/hc/en-us/articles/219576828" WHERE name="Discord";
DELETE FROM "providers" WHERE "name"="Discogs";
DELETE FROM "providers" WHERE "name"="Digital Surge";
DELETE FROM "providers" WHERE "name"="DCS World";
DELETE FROM "providers" WHERE "name"="Dext Prepare";
DELETE FROM "providers" WHERE "name"="Detectify";
DELETE FROM "providers" WHERE "name"="Deputy";
DELETE FROM "providers" WHERE "name"="Demio";
DELETE FROM "providers" WHERE "name"="Delinea";
DELETE FROM "providers" WHERE "name"="Deel";
DELETE FROM "providers" WHERE "name"="Datto";
DELETE FROM "providers" WHERE "name"="DataRobot";
DELETE FROM "providers" WHERE "name"="Databox";
DELETE FROM "providers" WHERE "name"="Current RMS";
DELETE FROM "providers" WHERE "name"="Crowd Supply";
DELETE FROM "providers" WHERE "name"="Credly";
DELETE FROM "providers" WHERE "name"="CrashPlan";
DELETE FROM "providers" WHERE "name"="Cal Poly Pomona";
DELETE FROM "providers" WHERE "name"="Coursera";
DELETE FROM "providers" WHERE "name"="Cordial";
DELETE FROM "providers" WHERE "name"="Constellix";
UPDATE "providers" SET help_url="https://help.compose.com/docs/two-factor-authentication" WHERE name="Compose";
DELETE FROM "providers" WHERE "name"="CommunityAmerica";
DELETE FROM "providers" WHERE "name"="Coinzilla";
DELETE FROM "providers" WHERE "name"="Cointraffic";
DELETE FROM "providers" WHERE "name"="CoinTiger";
UPDATE "providers" SET name="Coinspot" WHERE name="CoinSpot";
DELETE FROM "providers" WHERE "name"="CoinSmart";
DELETE FROM "providers" WHERE "name"="CoinRemitter";
DELETE FROM "providers" WHERE "name"="CoinPayU";
DELETE FROM "providers" WHERE "name"="CoinPayments";
DELETE FROM "providers" WHERE "name"="CoinLoan";
DELETE FROM "providers" WHERE "name"="Coinigy";
DELETE FROM "providers" WHERE "name"="CoinField";
DELETE FROM "providers" WHERE "name"="CoinDCX";
DELETE FROM "providers" WHERE "name"="Coinberry";
UPDATE "providers" SET help_url="https://support.coinbase.com/customer/en/portal/articles/1658338" WHERE name="Coinbase";
DELETE FROM "providers" WHERE "name"="Codeberg";
DELETE FROM "providers" WHERE "name"="Codebase";
DELETE FROM "providers" WHERE "name"="Coda";
UPDATE "providers" SET help_url="https://cobalt.io/blog/new-feature-two-factor-auth/" WHERE name="Cobalt";
DELETE FROM "providers" WHERE "name"="Clover";
DELETE FROM "providers" WHERE "name"="cloudHQ";
DELETE FROM "providers" WHERE "name"="CloudBees";
DELETE FROM "providers" WHERE "name"="CloudAMQP";
UPDATE "providers" SET help_url="https://blog.cloud66.com/two-factor-authentication-for-your-accounts/" WHERE name="Cloud 66";
DELETE FROM "providers" WHERE "name"="Oracle Cloud Infrastructure";
DELETE FROM "providers" WHERE "name"="Malwarebytes Nebula";
DELETE FROM "providers" WHERE "name"="HashiCorp Cloud Platform";
DELETE FROM "providers" WHERE "name"="Cliniko";
DELETE FROM "providers" WHERE "name"="ClickUp";
DELETE FROM "providers" WHERE "name"="CleverTap";
DELETE FROM "providers" WHERE "name"="ClearScore";
DELETE FROM "providers" WHERE "name"="Cisco";
DELETE FROM "providers" WHERE "name"="Checkfront";
DELETE FROM "providers" WHERE "name"="Chatwork";
DELETE FROM "providers" WHERE "name"="Google Chat";
UPDATE "providers" SET website="https://www.sophos.com" WHERE name="Sophos Central";
DELETE FROM "providers" WHERE "name"="Celsius";
DELETE FROM "providers" WHERE "name"="Caspio";
DELETE FROM "providers" WHERE "name"="Cash App";
DELETE FROM "providers" WHERE "name"="Cardmarket";
DELETE FROM "providers" WHERE "name"="Campaign Monitor";
DELETE FROM "providers" WHERE "name"="University of Cambridge";
DELETE FROM "providers" WHERE "name"="bunny.net";
DELETE FROM "providers" WHERE "name"="BullionVault";
DELETE FROM "providers" WHERE "name"="BullionStar";
DELETE FROM "providers" WHERE "name"="Buildium";
DELETE FROM "providers" WHERE "name"="Buhl";
UPDATE "providers" SET website="https://bufferapp.com", help_url="https://blog.bufferapp.com/introducing-the-safest-social-media-publishing-on-the-web" WHERE name="Buffer";
DELETE FROM "providers" WHERE "name"="Bubble";
DELETE FROM "providers" WHERE "name"="BtcTurk";
DELETE FROM "providers" WHERE "name"="Brex";
DELETE FROM "providers" WHERE "name"="Box";
DELETE FROM "providers" WHERE "name"="Bonusly";
DELETE FROM "providers" WHERE "name"="Bokio Sverige";
DELETE FROM "providers" WHERE "name"="BnkToTheFuture";
DELETE FROM "providers" WHERE "name"="BlueSnap";
UPDATE "providers" SET help_url="https://blockfi.com/blockfi-news/two-factor-authentication-2fa-now-available-for-all-blockfi-accounts/" WHERE name="BlockFi";
DELETE FROM "providers" WHERE "name"="Blockchain.com";
DELETE FROM "providers" WHERE "name"="BKEX";
UPDATE "providers" SET name="bitwarden" WHERE name="Bitwarden";
DELETE FROM "providers" WHERE "name"="Bitso";
DELETE FROM "providers" WHERE "name"="BitSight";
DELETE FROM "providers" WHERE "name"="Bitrise";
DELETE FROM "providers" WHERE "name"="BitForex";
DELETE FROM "providers" WHERE "name"="Bitbuy";
UPDATE "providers" SET help_url="https://confluence.atlassian.com/x/425QLg" WHERE name="Bitbucket";
DELETE FROM "providers" WHERE "name"="Bitbns";
DELETE FROM "providers" WHERE "name"="BitBar";
DELETE FROM "providers" WHERE "name"="Bill";
DELETE FROM "providers" WHERE "name"="Bibox";
DELETE FROM "providers" WHERE "name"="Barmenia";
DELETE FROM "providers" WHERE "name"="Baremetrics";
DELETE FROM "providers" WHERE "name"="Balena";
DELETE FROM "providers" WHERE "name"="Deutsche Bahn (DB)";
DELETE FROM "providers" WHERE "name"="Back4App";
DELETE FROM "providers" WHERE "name"="Awin";
DELETE FROM "providers" WHERE "name"="AVG";
DELETE FROM "providers" WHERE "name"="Avast";
DELETE FROM "providers" WHERE "name"="Automate.io";
DELETE FROM "providers" WHERE "name"="Auth0";
DELETE FROM "providers" WHERE "name"="Aussie Broadband";
DELETE FROM "providers" WHERE "name"="Audiense";
DELETE FROM "providers" WHERE "name"="Atera";
DELETE FROM "providers" WHERE "name"="Assembla";
DELETE FROM "providers" WHERE "name"="Asana";
DELETE FROM "providers" WHERE "name"="ARIN";
DELETE FROM "providers" WHERE "name"="Arduino";
DELETE FROM "providers" WHERE "name"="Flexera Software Vulnerability Research";
UPDATE "providers" SET help_url="https://support.anycoindirect.eu/hc/en-gb/articles/115001423191", name="AnycoinDirect" WHERE name="Anycoin Direct";
DELETE FROM "providers" WHERE "name"="ANY.RUN";
DELETE FROM "providers" WHERE "name"="AnonAddy";
DELETE FROM "providers" WHERE "name"="Amazing Marvin";
DELETE FROM "providers" WHERE "name"="Alterdice";
DELETE FROM "providers" WHERE "name"="AltCoinTrader";
DELETE FROM "providers" WHERE "name"="Allegro";
DELETE FROM "providers" WHERE "name"="Alchemer";
DELETE FROM "providers" WHERE "name"="Aiven";
DELETE FROM "providers" WHERE "name"="Adyen";
DELETE FROM "providers" WHERE "name"="Activision";
DELETE FROM "providers" WHERE "name"="ActiveCampaign";
DELETE FROM "providers" WHERE "name"="Actionstep";
DELETE FROM "providers" WHERE "name"="Accelo";
DELETE FROM "providers" WHERE "name"="Contra Costa Community College District";
DELETE FROM "providers" WHERE "name"="3Commas";
DELETE FROM "providers" WHERE "name"="2Checkout";
DELETE FROM "providers" WHERE "name"="15Five";
DELETE FROM "providers" WHERE "name"="123 Form Builder";
